OC.L10N.register(
    "spreed",
    {
    "a conversation" : "bir görüşme",
    "(Duration %s)" : "(Süre %s)",
    "You attended a call with {user1}" : "{user1} ile bir çağrıya katıldınız",
    "_%n guest_::_%n guests_" : ["%n konuk","%n konuk"],
    "You attended a call with {user1} and {user2}" : "{user1} ve {user2} ile bir çağrıya katıldınız",
    "You attended a call with {user1}, {user2} and {user3}" : "{user1}, {user2} ve {user3} ile bir çağrıya katıldınız",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "{user1}, {user2}, {user3} ve {user4} ile bir çağrıya katıldınız",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "{user1}, {user2}, {user3}, {user4} ve {user5} ile bir çağrıya katıldınız",
    "_%n other_::_%n others_" : ["%n diğer","%n diğer"],
    "{actor} invited you to {call}" : "{actor} sizi {call} için çağırdı",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Bir <strong>görüşmeye davet edildiğinizde</strong> ya da bir <strong>davet</strong> aldığınızda",
    "Other activities" : "Diğer işlemler",
    "Talk" : "Konuş",
    "Guest" : "Konuk",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Nextcloud Konuş uygulamasına hoş geldiniz!\nBu görüşmede yeni Nextcloud Konuş özellikleri hakkında bilgilendirileceksiniz.",
    "## New in Talk %s" : "## Konuş %s uygulamasındaki yenilikler",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Sesli ve görüntülü çağrılara katılmak için Microsoft Edge ve Safari kullanılabilir",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Bire bir görüşmeler artık kalıcı oldu ve bunların kazayla grup görüşmelerine dönüştürülmesi engellendi. Ayrıca artık katılımcılardan biri görüşmeden ayrıldığında, görüşme otomatik olarak silinmiyor. Görüşme ancak her iki katılımcı da ayrılırsa sunucudan siliniyor.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Artık sohbet sırasında \"@all\" yazarak tüm katılımcıları bilgilendirebilirsiniz",
    "- With the \"arrow-up\" key you can repost your last message" : "- \"Yukarı ok\" tuşuyla son iletinizi çağırabilirsiniz",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Konuş üzerinde artık komutlar kullanılabilir, Yöneticinizin yapılandırdığı komutlar varsa \"/help\" yazıp göndererek sohbet iletisi olarak görebilirsiniz ",
    "- With projects you can create quick links between conversations, files and other items" : "- Projeleri kullanarak görüşmeler, dosyalar ve diğer ögeler arasında hızlı bağlantılar oluşturabilirsiniz",
    "- You can now mention guests in the chat" : "- Artık sohbetteki konukları anabilirsiniz",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Artık görüşmelerin bir girişi olabiliyor. Böylece kullanıcılar ve konuklar beklerken sorumlular önceden görüşmeye ya da çağrıya katılıp gerekli hazırlıkları yapabiliyor",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Artık diğer kullanıcılara iletinizin ne hakkında olduğu ile ilgili daha fazla bilgi vererek iletileri doğrudan yanıtlayabilirsiniz.",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Artık görüşme ve katılımcı aramalarında var olan görüşmeleriniz de süzülür. Böylece yakın zamandaki görüşmeler daha kolay bulunabilir",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Takımlar uygulaması kurulduğunda görüşmelere özel kullanıcı grupları eklenebilir",
    "- Check out the new grid and call view" : "- Yeni tablo ve çağrı görünümleri",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Artık dosyaları doğrudan aygıtınızdan sürükleyip bırakarak ya da yükleyerek sohbete aktarabilirsiniz",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Paylaşılan dosyalar artık doğrudan sohbet görünümünde görüntüleyici uygulamalar ile açılabilir",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Artık sohbet ve iletileri üst çubuktaki birleşik aramayı kullanarak arayabilirsiniz",
    "- Spice up your messages with emojis from the emoji picker" : "- İletilerinizi emoji seçiciden ekleyeceğiniz emojiler ile zenginleştirin",
    "- You can now change your camera and microphone while being in a call" : "- Artık bir çağrı sürerken kamera ve mikrofonunuzu değiştirebilirsiniz",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Görüşmelerinize bir açıklama ekleyerek kapsamını belirleyip açabilirsiniz. Böylece oturum açmış kullanıcılar görüşmeyi bularak kendi kendilerine katılabilir",
    "- See a read status and send failed messages again" : "- Okunma durumunu görerek gönderilmeyen iletileri yeniden gönderebilirsiniz",
    "- Raise your hand in a call with the R key" : "- Çağrılarda R tuşuna basarak el kaldırabilirsiniz",
    "- Join the same conversation and call from multiple devices" : "- Aynı görüşmeye katılın ve çeşitli aygıtlardan çağrı yapın",
    "- Send voice messages, share your location or contact details" : "- Sesli iletiler gönderin, konumunuzu veya iletişim bilgilerinizi paylaşın",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Bir görüşmeye gruplar ekleyin ve yeni grup üyelerinin otomatik olarak katılmasını sağlayın",
    "- A preview of your audio and video is shown before joining a call" : "- Bir çağrıya katılmadan önce sesinizin ve görüntünüzün ön izlemesi sunulur",
    "- You can now blur your background in the newly designed call view" : "- Artık yeni tasarlanmış çağrı görünümünde arka planınızı bulanıklaştırabilirsiniz",
    "- Moderators can now assign general and individual permissions to participants" : "- Artık sorumlular katılımcılara genel ve kişisel izinler atayabilir",
    "- You can now react to chat messages" : "- Artık sohbet iletilerine tepki verebilirsiniz",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Artık kenar çubuğunda son paylaşılan ögelerin özetini görebilirsiniz",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Başkalarının görüşlerini almak ya da bir tarih belirlemek için bir anket kullanın",
    "- Configure an expiration time for chat messages" : "- Sohbet iletileri için bir geçerlilik süresi yapılandırın",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Büyük görüşmelerde bildirim göndermeden çağrı başlatın. Çağrı başladıktan sonra bireysel çağrı bildirimleri gönderebilirsiniz.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Acil değilse sohbet iletilerine alıcılara bildirim olmadan gönderin",
    "- Emojis can now be autocompleted by typing a \":\"" : "- \".\" yazarak emojiler otomatik olarak tamamlanabilir",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- \"/\" yazarak yeni akıllı seçici ile çeşitli ögeler bağlanabilir",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Sorumlular çalışma odaları oluşturabilir (yüksek başarımlı arka yüz gereklidir)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Çağrılar kaydedilebilir (yüksek başarımlı arka yüz gereklidir)",
    "- Conversations can now have an avatar or emoji as icon" : "- Görüşmelerde artık simge olarak bir avatar ya da emoji kullanılabilir",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Görüntülü aramalarda bulanık arka planın yanında artık sanal arka planlar da kullanılabilir",
    "- Reactions are now available during calls" : "- Artık aramalarda tepkiler kullanılabilir",
    "- Typing indicators show which users are currently typing a message" : "- Yazma göstergeleri, o anda hangi kullanıcıların ileti yazdığını gösterir",
    "- Groups can now be mentioned in chats" : "- Artık sohbetlerde gruplar anılabilir",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Bir yazı dönüştürme hizmeti ayarlandıysa arama kayıtları otomatik olarak yazıya dönüştürülür",
    "- Chat messages can be translated if a translation provider app is registered" : "- Bir çeviri hizmeti ayarlandıysa sohbet iletileri başka dile çevrilebilir",
    "- **Markdown** can now be used in _chat_ messages" : "- _chat_ iletilerinde artık **markdown** kullanılabilir",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- İnternet kancaları artık botları uygulamak için kullanılabilir. Ayrıntılı bilgi almak için https://nextcloud-talk.readthedocs.io/en/latest/bot-list/ adresine bakabilirsiniz",
    "- Set a reminder on a chat message to be notified later again" : "- Daha sonra yeniden bilgilendirilmek için bir sohbet iletisine bir anımsatıcı ayarlayın",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Aygıtlarınız arasında not almak ve bilgi paylaşmak için **Kendime not** yazışmasını kullanın",
    "- Captions allow to send a message with a file at the same time" : "- Alt yazılar aynı anda bir dosyayla birlikte bir ileti göndermeyi sağlar",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Artık ekran paylaşılırken konuşmacının görüntüsü görülebiliyor ve çağrı tepkileri canlandırılıyor",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- İletilerin oturum açmış yazarlar ve sorumlular tarafından ilk 6 saat içinde düzenlenebilmesi sağlandı",
    "- Unsent message drafts are now saved in your browser" : "- Gönderilmemiş ileti taslaklarının tarayıcınıza kaydedilmesi sağlandı",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Yazılı sohbetlerin diğer Konuş sunucularıyla birleşik olarak yapılabilmesi sağlandı",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Sorumlular artık hesapları ve misafirleri yasaklayarak bir görüşmeye yeniden katılmalarını önleyebilir",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Görüşmelerde bağlantılı takvim etkinliklerinden gelen çağrıların ve ofis dışındayken yedek kişilerin görüntülenmesi sağlandı",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Çağrıların diğer Konuş sunucularıyla birleşik olarak yapılabilmesi sağlandı (yüksek başarımlı arka yüz gereklidir)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Windows, macOS ve Linux için Nextcloud Konuş bilgisayar istemcisini sunarız: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Nextcloud Yardımcı ile sohbetlerdeki çağrı kayıtlarını ve okunmamış iletileri özetleyin",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Toplantılar, e-posta adresleri ile davet edilen misafirleri tanıma, katılımcı listelerini içe aktarma, anketler için taslaklar ve çağrı katılımcı listelerinin indirilmesiyle iyileştirildi",
    "- Archive conversations to stay focused" : "- Odaklanmak için görüşmeleri arşivleyin",
    "- Schedule a meeting into your calendar from within a conversation" : "- Bir görüşmenin içinden takviminizde bir toplantı zamanlayın",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Geçerli görüşmenin iletilerini doğrudan sağ kenar çubuğunda arayın",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Yeni küçük listeyle daha fazla görüşmeyi bir kerede görün (Konuş ayarlarından açın)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Toplantı görüşmelerinin artık takvimdeki başlıkları ve açıklamaları eşitleniyor ve başlangıç zamanları yaklaşana kadar bunlar bir arama süzgeciyle gizleniyor",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- İleti içeriğini görüşme listesinden ve bildirimlerden gizlemek için bildirim ayarlarında konuşmaları ciddi olarak işaretleyebilirsiniz",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- \"Rahatsız etmeyin\" durumunda anlık bildirimleri almak için görüşmeleri önemli olarak işaretleyebilirsiniz",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Anında yeni bir grup görüşmesi oluşturmak için bire bir görüşmeye başka katılımcılar ekleyin",
    "- Use threads to keep your chat and discussions organized" : "- Sohbetlerinizi ve tartışmalarınızı düzenli tutmak için yazışmaları kullanın",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Arama sırasında artık canlı yazıya dönüştürme kullanılabilir (canlı yazıya dönüştürme ExApp ve Yüksek başarımlı arka uç gereklidir)",
    "- Moderators can now pin messages so they are kept at the top" : "- Sorumlular artık iletileri sabitleyerek en üstte kalmalarını sağlayabilir",
    "- Schedule a message to send it at a later time" : "- Bir iletiyi daha sonra gönderilmek üzere planlayın",
    "_All %n participant_::_All %n participants_" : ["Tüm %n katılımcı","Tüm %n katılımcı"],
    "Talk updates ✅" : "Konuş güncellemeleri ✅",
    "Reaction deleted by author" : "Tepki yazarı tarafından silindi",
    "{actor} created the conversation" : "{actor} görüşme ekledi",
    "You created the conversation" : "Görüşme eklediniz",
    "System created the conversation" : "Sistem görüşme ekledi",
    "An administrator created the conversation" : "Bir yönetici görüşme ekledi",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor}, görüşmenin \"%1$s\" olan adını \"%2$s\" olarak değiştirdi",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "\"%1$s\" görüşmesinin adını \"%2$s\" olarak değiştirdiniz",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Bir yönetici, görüşmenin \"%1$s\" olan adını \"%2$s\" olarak değiştirdi",
    "{actor} set the description" : "{actor} açıklamayı ayarladı",
    "You set the description" : "Açıklamayı ayarladınız",
    "An administrator set the description" : "Bir yönetici açıklamayı ayarladı",
    "{actor} removed the description" : "{actor} açıklamayı kaldırdı",
    "You removed the description" : "Açıklamayı kaldırdınız",
    "An administrator removed the description" : "Bir yönetici açıklamayı kaldırdı",
    "You started a silent call" : "Bir sessiz çağrı başlattınız",
    "Outgoing silent call" : "Giden sessiz çağrı",
    "{actor} started a silent call" : "{actor} bir sessiz çağrı başlattı",
    "Incoming silent call" : "Gelen sessiz çağrı",
    "You started a call" : "Bir çağrı başlattınız",
    "Outgoing call" : "Giden çağrı",
    "{actor} started a call" : "{actor} bir çağrı başlattı",
    "Incoming call" : "Gelen çağrı",
    "{actor} joined the call" : "{actor} çağrıya katıldı",
    "You joined the call" : "Bir çağrıya katıldınız",
    "{actor} left the call" : "{actor} çağrıdan ayrıldı",
    "You left the call" : "Bir çağrıdan ayrıldınız",
    "{actor} unlocked the conversation" : "{actor} görüşmenin kilidini açtı",
    "You unlocked the conversation" : "Görüşmenin kilidini açtınız",
    "An administrator unlocked the conversation" : "Bir yönetici görüşmenin kilidini açtı",
    "{actor} locked the conversation" : "{actor} görüşmeyi kilitledi",
    "You locked the conversation" : "Görüşmeyi kilitlediniz",
    "An administrator locked the conversation" : "Bir yönetici görüşmeyi kilitledi",
    "{actor} limited the conversation to the current participants" : "{actor} görüşmeyi geçerli katılımcılar ile kısıtladı",
    "You limited the conversation to the current participants" : "Görüşmeyi geçerli katılımcılar ile kısıtladınız",
    "An administrator limited the conversation to the current participants" : "Bir yönetici görüşmeyi geçerli katılımcılar ile kısıtladı",
    "{actor} opened the conversation to registered users" : "{actor} görüşmeyi hesabı olan kullanıcılara açtı",
    "You opened the conversation to registered users" : "Görüşmeyi hesabı olan kullanıcılara açtınız",
    "An administrator opened the conversation to registered users" : "Bir yönetici görüşmeyi hesabı olan kullanıcılara açtı",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} görüşmeyi hesabı olan kullanıcılara ve Konuklar uygulaması ile oluşturulan kullanıcılara açtı",
    "You opened the conversation to registered users and users created with the Guests app" : "Görüşmeyi hesabı olan kullanıcılara ve Konuklar uygulaması ile oluşturulan kullanıcılara açtınız",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Bir yönetici görüşmeyi hesabı olan kullanıcılara ve Konuklar uygulaması ile oluşturulan kullanıcılara açtı",
    "The conversation is now open to everyone" : "Görüşme şu anda herkese açık",
    "{actor} opened the conversation to everyone" : "{actor} görüşmeyi herkese açtı",
    "You opened the conversation to everyone" : "Görüşmeyi herkese açtınız",
    "{actor} restricted the conversation to moderators" : "{actor} görüşmeyi sorumlular ile kısıtladı",
    "You restricted the conversation to moderators" : "Görüşmeyi sorumlular ile kısıtladınız",
    "{actor} started breakout rooms" : "{actor} çalışma odalarını açtı",
    "You started breakout rooms" : "Çalışma odalarını açtınız",
    "{actor} stopped breakout rooms" : "{actor} çalışma odalarını kapattı",
    "You stopped breakout rooms" : "Çalışma odalarını kapattınız",
    "{actor} allowed guests" : "{actor} konukların katılmasına izin verdi",
    "You allowed guests" : "Konukların katılmasına izin verdiniz",
    "An administrator allowed guests" : "Bir yönetici konukların katılmasına izin verdi",
    "{actor} disallowed guests" : "{actor} konukların katılmasını engelledi",
    "You disallowed guests" : "Konukların katılmasını engellediniz",
    "An administrator disallowed guests" : "Bir yönetici konukların katılmasını engelledi",
    "{actor} set a password" : "{actor} bir parola atadı",
    "You set a password" : "Bir parola atadınız",
    "An administrator set a password" : "Bir yönetici bir parola atadı",
    "{actor} removed the password" : "{actor} parolayı kaldırdı",
    "You removed the password" : "Parolayı kaldırdınız",
    "An administrator removed the password" : "Bir yönetici parolayı kaldırdı",
    "{actor} added {user}" : "{actor}, {user} kullanıcısını ekledi",
    "You joined the conversation" : "Görüşmeye katıldınız",
    "{actor} joined the conversation" : "{actor} görüşmeye katıldı",
    "You added {user}" : "{user} kullanıcısını eklediniz",
    "{actor} added you" : "{actor} sizi ekledi",
    "An administrator added you" : "Bir yönetici sizi ekledi",
    "An administrator added {user}" : "Bir yönetici, {user} kullanıcısını ekledi",
    "You left the conversation" : "Görüşmeden ayrıldınız",
    "{actor} left the conversation" : "{actor} görüşmeden ayrıldı",
    "{actor} removed {user}" : "{actor}, {user} kullanıcısını çıkardı",
    "You removed {user}" : "{user} kullanıcısını çıkardınız",
    "{actor} removed you" : "{actor} sizi çıkardı",
    "An administrator removed you" : "Bir yönetici sizi çıkardı",
    "An administrator removed {user}" : "Bir yönetici, {user} kullanıcısını çıkardı",
    "{actor} invited {federated_user}" : "{actor}, {federated_user} kullanıcısını davet etti",
    "You invited {federated_user}" : "{federated_user} kullanıcısını davet ettiniz",
    "You accepted the invitation" : "Daveti kabul ettiniz",
    "{actor} invited you" : "{actor} sizi davet etti",
    "An administrator invited you" : "Bir yönetici sizi davet etti",
    "An administrator invited {federated_user}" : "Bir yönetici, {federated_user} kullanıcısını davet etti",
    "{federated_user} accepted the invitation" : "{federated_user} daveti kabul etti",
    "{actor} removed {federated_user}" : "{actor}, {federated_user} kullanıcısını çıkardı",
    "You removed {federated_user}" : "{federated_user} kullanıcısını çıkardınız",
    "You declined the invitation" : "Daveti reddettiniz",
    "An administrator removed {federated_user}" : "Bir yönetici, {federated_user} kullanıcısını çıkardı",
    "{federated_user} declined the invitation" : "{federated_user} daveti reddetti",
    "{actor} added group {group}" : "{actor}, group} grubunu ekledi",
    "You added group {group}" : "{group} grubunu eklediniz",
    "An administrator added group {group}" : "Bir yönetici {group} grubunu ekledi",
    "{actor} removed group {group}" : "{actor}, {group} grubunu sildi",
    "You removed group {group}" : "{group} grubunu sildiniz",
    "An administrator removed group {group}" : "Bir yönetici {group} grubunu sildi",
    "{actor} added team {circle}" : "{actor}, {circle} takımını ekledi",
    "You added team {circle}" : "{circle} takımını eklediniz",
    "An administrator added team {circle}" : "Bir yönetici {circle} takımını ekledi",
    "{actor} removed team {circle}" : "{actor}, {circle} takımını ekledi",
    "You removed team {circle}" : "{circle} takımını eklediniz",
    "An administrator removed team {circle}" : "Bir yönetici {circle} takımını sildi",
    "{actor} added {phone}" : "{actor}, {phone} numarasını ekledi",
    "You added {phone}" : "{phone} numarasını eklediniz",
    "An administrator added {phone}" : "Bir yönetici {phone} numarasını ekledi",
    "{actor} removed {phone}" : "{actor}, {phone} numarasını kaldırdı",
    "You removed {phone}" : "{phone} numarasını kaldırdınız",
    "An administrator removed {phone}" : "Bir yönetici {phone} numarasını kaldırdı",
    "{actor} promoted {user} to moderator" : "{actor}, {user} kullanıcısını sorumluluğa yükseltti",
    "You promoted {user} to moderator" : "{user} kullanıcısını sorumluluğa yükselttiniz",
    "{actor} promoted you to moderator" : "{actor} sizi sorumluluğa yükseltti",
    "An administrator promoted you to moderator" : "Bir yönetici sizi sorumluluğa yükseltti",
    "An administrator promoted {user} to moderator" : "Bir yönetici, {user} kullanıcısını sorumluluğa yükseltti",
    "{actor} demoted {user} from moderator" : "{actor}, {user} kullanıcısını sorumluluktan çıkardı",
    "You demoted {user} from moderator" : "{user} kullanıcısını sorumluluktan çıkardınız",
    "{actor} demoted you from moderator" : "{actor}, sizi sorumluluktan çıkardı",
    "An administrator demoted you from moderator" : "Bir yönetici, sizi sorumluluktan çıkardı",
    "An administrator demoted {user} from moderator" : "Bir yönetici, {user} kullanıcısını sorumluluktan çıkardı",
    "{actor} shared a file which is no longer available" : "{actor} artık kullanılamayan bir dosya paylaştı",
    "You shared a file which is no longer available" : "Artık kullanılamayan bir dosya paylaştınız",
    "File shares are currently not supported in federated conversations" : "Şu anda birleşik görüşmelerde dosya paylaşımı desteklenmiyor",
    "The shared location is malformed" : "Paylaşılmış konum biçimi hatalı",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} bu görüşmeyi diğer sohbetler ile eşitlemek için Matterbridge kurulumu yaptı",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Bu görüşmeyi diğer sohbetler ile eşitlemek için Matterbridge kurulumu yaptınız",
    "{actor} created thread {title}" : "{actor}, {title} yazışmasını oluşturdu",
    "You created thread {title}" : "{title} yazışmasını oluşturdunuz",
    "{actor} renamed thread {title}" : "{actor}, {title} yazışmasını yeniden adlandırdı",
    "You renamed thread {title}" : "{title} yazışmasını yeniden adlandırdınız",
    "{actor} updated the Matterbridge configuration" : "{actor} Matterbridge yapılandırmasını güncelledi",
    "You updated the Matterbridge configuration" : "Matterbridge yapılandırmasını güncellediniz",
    "{actor} removed the Matterbridge configuration" : "{actor} Matterbridge yapılandırmasını sildi",
    "You removed the Matterbridge configuration" : "Matterbridge yapılandırmasını sildiniz",
    "{actor} started Matterbridge" : "{actor} Matterbridge uygulamasını başlattı",
    "You started Matterbridge" : "Matterbride uygulamasını başlattınız",
    "{actor} stopped Matterbridge" : "{actor} Matterbridge uygulamasını durdurdu",
    "You stopped Matterbridge" : "Matterbride uygulamasını durdurdunuz",
    "{actor} deleted a message" : "{actor} bir iletiyi sildi",
    "You deleted a message" : "Bir iletiyi sildiniz",
    "{actor} edited a message" : "{actor} bir iletiyi düzenledi",
    "You edited a message" : "Bir iletiyi düzenlediniz",
    "{actor} pinned a message" : "{actor} bir iletiyi sabitledi",
    "You pinned a message" : "Bir iletiyi sabitlediniz",
    "{actor} unpinned a message" : "{actor} bir iletinin sabitlemesini kaldırdı",
    "Message was automatically unpinned" : "İletinin sabitlemesi otomatik olarak kaldırıldı",
    "You unpinned a message" : "Bir iletinin sabitlemesini kaldırdınız",
    "{actor} deleted a reaction" : "{actor} bir tepkiyi sildi",
    "You deleted a reaction" : "Bir tepkiyi sildiniz",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["İletinin geçerlilik süresini %n hafta olarak ayarladınız","İletinin geçerlilik süresini %n hafta olarak ayarladınız"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["İletinin geçerlilik süresini %n gün olarak ayarladınız","İletinin geçerlilik süresini %n gün olarak ayarladınız"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["İletinin geçerlilik süresini %n saat olarak ayarladınız","İletinin geçerlilik süresini %n saat olarak ayarladınız"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["İletinin geçerlilik süresini %n dakika olarak ayarladınız","İletinin geçerlilik süresini %n dakika olarak ayarladınız"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} iletinin geçerlilik süresini %n hafta olarak ayarladı","{actor} iletinin geçerlilik süresini %n hafta olarak ayarladı"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} iletinin geçerlilik süresini %n gün olarak ayarladı","{actor} iletinin geçerlilik süresini %n gün olarak ayarladı"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} iletinin geçerlilik süresini %n saat olarak ayarladı","{actor} iletinin geçerlilik süresini %n saat olarak ayarladı"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} iletinin geçerlilik süresini %n dakika olarak ayarladı","{actor} iletinin geçerlilik süresini %n dakika olarak ayarladı"],
    "{actor} disabled message expiration" : "{actor} ileti geçerlilik süresini kapattı",
    "You disabled message expiration" : "İleti geçerlilik süresini kapattınız",
    "{actor} cleared the history of the conversation" : "{actor} görüşme geçmişini sildi",
    "You cleared the history of the conversation" : "Görüşme geçmişini sildiniz",
    "{actor} set the conversation picture" : "{actor} görüşme görselini ayarladı",
    "You set the conversation picture" : "Görüşme görselini ayarladınız",
    "{actor} removed the conversation picture" : "{actor} görüşme görselini kaldırdı",
    "You removed the conversation picture" : "Görüşme görselini kaldırdınız",
    "{actor} ended the poll {poll}" : "{actor}, {poll} anketini sona erdirdi.",
    "You ended the poll {poll}" : "{poll} anketini sona erdirdiniz",
    "{actor} started the video recording" : "{actor} görüntü kaydını başlattı",
    "You started the video recording" : "Görüntü kaydını başlattınız",
    "{actor} stopped the video recording" : "{actor} görüntü kaydını bitirdi",
    "You stopped the video recording" : "Görüntü kaydını bitirdiniz",
    "{actor} started the audio recording" : "{actor} ses kaydını başlattı",
    "You started the audio recording" : "Ses kaydını başlattınız",
    "{actor} stopped the audio recording" : "{actor} ses kaydını bitirdi",
    "You stopped the audio recording" : "Ses kaydını bitirdiniz",
    "The recording failed" : "Kayıt yapılamadı",
    "Someone voted on the poll {poll}" : "Birisi {poll} anketinde oy verdi",
    "Message deleted by author" : "İleti yazarı tarafından silindi",
    "Message deleted by {actor}" : "İleti {actor} tarafından silindi",
    "Message deleted by you" : "İleti sizin tarafınızdan silindi",
    "Deleted user" : "Kullanıcıyı sildi ",
    "Unknown number" : "Numara bilinmiyor",
    "Administration" : "Yönetim",
    "System" : "Sistem",
    "%s (guest)" : "%s (konuk)",
    "Missed call" : "Yanıtsız çağrı",
    "Unanswered call" : "Yanıtlanmamış çağrı",
    "Call ended (Duration {duration})" : "Çağrı sonlandırıldı (Süre {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Çağrı, en uzun çağrı süresi sınırına ulaşıldığından sonlandırıldı (Süre {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} çağrıyı sonlandırdı (Süre {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["%n konuk bulunan çağrı en uzun çağrı süresi sınırına ulaşıldığından sonlandırıldı (Süre {duration})","%n konuk bulunan çağrı en uzun çağrı süresi sınırına ulaşıldığından sonlandırıldı (Süre {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["%n konuk ile çağrı sonlandırıldı (Süre {duration})","%n konuk ile çağrı sonlandırıldı (Süre {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor}, %n konukla çağrıyı sonlandırdı (Süre {duration})","{actor}, %n konukla çağrıyı sonlandırdı (Süre {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1} ile çağrı en uzun çağrı süresi sınırına ulaşıldığından sonlandırıldı (Süre {duration})",
    "Call with {user1} ended (Duration {duration})" : "{user1} ile çağrı sonlandırıldı (Süre {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor}, {user1} ile çağrıyı sonlandırdı (Süre {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1} ve {user2} ile çağrı en uzun çağrı süresi sınırına ulaşıldığından sonlandırıldı (Süre {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "{user1} ve {user2} ile çağrı sonlandırıldı (Süre {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor}, {user1} ve {user2} ile çağrıyı sonlandırdı (Süre {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1}, {user2} ve {user3} ile çağrı en uzun çağrı süresi sınırına ulaşıldığından sonlandırıldı (Süre {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "{user1}, {user2} ve {user3} ile çağrı sonlandırıldı (Süre {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor}, {user1}, {user2} ve {user3} ile çağrıyı sonlandırdı (Süre {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1}, {user2}, {user3} ve {user4} ile çağrı en uzun çağrı süresi sınırına ulaşıldığından sonlandırıldı (Süre {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "{user1}, {user2}, {user3} ve {user4} ile çağrı sonlandırıldı (Süre {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor}, {user1}, {user2}, {user3} ve {user4} ile çağrıyı sonlandırdı (Süre {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "{user1}, {user2}, {user3}, {user4} ve {user5} ile çağrı en uzun çağrı süresi sınırına ulaşıldığından sonlandırıldı (Süre {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "{user1}, {user2}, {user3}, {user4} ve {user5} ile çağrı sonlandırıldı (Süre {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor}, {user1}, {user2}, {user3}, {user4} ve {user5} ile çağrıyı sonlandırdı (Süre {duration})",
    "Message of {user} in {conversation}" : "{conversationName} görüşmesinde {user} iletisi",
    "Message of {user}" : "{user} iletisi",
    "Message of a deleted user in {conversation}" : "{conversationName} görüşmesinde silinmiş bir kullanıcının iletisi",
    "Talk conversations" : "Konuş görüşmeleri",
    "Talk to %s" : "%s ile Konuş",
    "An error occurred. Please contact your administrator." : "Bir sorun çıktı. Lütfen BT yöneticiniz ile görüşün.",
    "Storage quota exceeded" : "Depolama sınırına ulaşıldı",
    "File not found" : "Dosya bulunamadı",
    "File is not shared, or shared but not with the user" : "Dosya paylaşılmamış ya da paylaşılmış ancak kullanıcı ile değil.",
    "No account available to delete." : "Silinebilecek bir hesap yok.",
    "Poll" : "Anket",
    "Password needs to be set" : "Parola ayarlanmalıdır",
    "Uploading the file failed" : "Dosya yüklenemedi",
    "No image file provided" : "Bir görsel dosyası belirtilmemiş",
    "File is too big" : "Dosya çok büyük",
    "Invalid file provided" : "Belirtilen dosya geçersiz",
    "Invalid image" : "Görsel geçersiz",
    "Unknown filetype" : "Dosya türü bilinmiyor",
    "Talk mentions" : "Konuş anmaları",
    "More conversations" : "Diğer görüşmeler",
    "Say hi to your friends and colleagues!" : "Tanıdık ve çalışma arkadaşlarınıza selam verin!",
    "No unread mentions" : "Okunmamış bir anma yok",
    "Call in progress" : "Çağrı sürüyor",
    "You were mentioned" : "Anıldınız",
    "Write to conversation" : "Görüşmeye yaz",
    "Writes event information into a conversation of your choice" : "Etkinlik bilgilerini isteğinize göre bir görüşmeye yazar",
    "Missing email field in header line" : "Başlık satırında e-posta alanı eksik",
    "Following lines are invalid: %s" : "Şu satırlar geçersiz: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s sizi \"%2$s\" görüşmesine davet etti.",
    "You were invited to conversation \"%s\"." : "\"%s\" görüşmesine davet edildiniz.",
    "Conversation invitation" : "Görüşme daveti",
    "Scheduled time" : "Planmış zaman",
    "Description" : "Açıklama",
    "You can also dial-in via phone with the following details" : "Ayrıca şu bilgileri kullanarak telefon ile arayabilirsiniz",
    "Dial-in information" : "Çevirme bilgileri",
    "Meeting ID" : "Toplantı kimliği",
    "Your PIN" : "PIN numaranız",
    "Click the button below to join the lobby now." : "Girişte beklemek için aşağıdaki düğmeye tıklayın.",
    "Click the link below to join the lobby now." : "Girişte beklemek için aşağıdaki bağlantıya tıklayın.",
    "Join lobby for \"%s\"" : "\"%s\" girişinde bekleyin",
    "Click the button below to join the conversation now." : "Görüşmeye katılmak için aşağıdaki düğmeye tıklayın.",
    "Click the link below to join the conversation now." : "Görüşmeye katılmak için aşağıdaki bağlantıya tıklayın.",
    "Join \"%s\"" : "\"%s\" görüşmesine katıl",
    "Meeting" : "Toplantı",
    "Password request: %s" : "Parola isteği: %s",
    "Private conversation" : "Özel görüşme",
    "Deleted user (%s)" : "Silinmiş kullanıcı (%s)",
    "Failed to upload call recording" : "Çağrı kaydı yüklenemedi",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Kayıt sunucusu {call} çağrısının kaydını yüklemedi. Lütfen yönetim ile görüşün.",
    "Share to chat" : "Sohbet ile paylaş",
    "Dismiss notification" : "Bildirimi yok say",
    "Call recording now available" : "Çağrı kaydedilebilir",
    "The recording for the call in {call} was uploaded to {file}." : "{call} çağrısının kaydı {file} dosyasına yüklendi.",
    "Transcript now available" : "Çağrıyı yazıya dönüştürme kullanılabilir",
    "The transcript for the call in {call} was uploaded to {file}." : "{call} çağrısı yazıya dönüştürüldü ve {file} dosyasına yüklendi.",
    "Failed to transcript call recording" : "Çağrı kaydı yazıya dönüştürülemedi",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Sunucu {call} çağrısının kaydını {file} yazıya dönüştüremedi. Lütfen yönetim ile görüşün.",
    "Call summary now available" : "Çağrı özeti kullanılabilir",
    "The summary for the call in {call} was uploaded to {file}." : "{call} çağrısının özeti {file} dosyasına yüklendi.",
    "Failed to summarize call recording" : "Çağrı kaydı özetlenemedi",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Sunucu {call} çağrısının kaydından {file} özet dosyasını oluşturamadı. Lütfen yönetim ile görüşün.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} sizi {remoteServer} üzerindeki {roomName} grubuna katılmaya davet etti",
    "Accept" : "Kabul et",
    "Decline" : "Reddet",
    "{user1} invited you to a federated conversation" : "{user} sizi bir birleşik görüşmeye davet etti",
    "Someone reacted" : "Biri tepki verdi ",
    "New message" : "Yeni ileti",
    "Reminder" : "Anımsatıcı",
    "Someone mentioned you" : "Biri sizi andı",
    "Notification" : "Bildirim",
    "Someone reacted in a private conversation" : "Biri özel bir görüşmede tepki verdi",
    "You received a message in a private conversation" : "Bir özel görüşmede bir ileti aldınız",
    "Reminder in a private conversation" : "Özel bir görüşmede anımsatıcı",
    "Someone mentioned you in a private conversation" : "Biri özel bir görüşmede sizi andı",
    "Notification in a private conversation" : "Özel bir görüşmede bildirim",
    "Reminder: You in {call}" : "Anımsatma: {call} görüşmesindesiniz",
    "Reminder: {user} in {call}" : "Anımsatma: {user}, {call} görüşmesinde",
    "Reminder: Deleted user in {call}" : "Anımsatma: Silinmiş kullanıcı {call} görüşmesinde",
    "Reminder: {guest} (guest) in {call}" : "Anımsatma: {guest} (konuk) {call} görüşmesinde",
    "Reminder: Guest in {call}" : "Anımsatma: Konuk {call} görüşmesinde",
    "{user} reacted with {reaction}" : "{user}, {reaction} tepkisini verdi",
    "{user} reacted with {reaction} in {call}" : "{user}, {call} çağrısında {reaction} tepkisini verdi",
    "Deleted user reacted with {reaction} in {call}" : "Silinmiş kullanıcı {call} çağrısında {reaction} tepkisini verdi",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (konuk), {call} çağrısında {reaction} tepkisini verdi",
    "Guest reacted with {reaction} in {call}" : "Konuk, {call} çağrısında {reaction} tepkisini verdi",
    "{user} in {call}" : "{call} içinde {user}",
    "Deleted user in {call}" : "{call} içinden kullanıcı silindi",
    "{guest} (guest) in {call}" : "{call} içinde {guest} (konuk)",
    "Guest in {call}" : "{call} içinde konuk",
    "{user} sent you a private message" : "{user} size kişisel bir ileti gönderdi",
    "{user} sent a message in conversation {call}" : "{user}, {call} görüşmesine bir ileti gönderdi",
    "A deleted user sent a message in conversation {call}" : "Silinmiş bir kullanıcı {call} görüşmesine bir ileti gönderdi",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (konuk) {call} görüşmesine bir ileti gönderdi",
    "A guest sent a message in conversation {call}" : "Bir konuk {call} görüşmesine bir ileti gönderdi",
    "{user} replied to your private message" : "{user} kişisel iletinizi yanıtladı",
    "{user} replied to your message in conversation {call}" : "{user} iletinizi {call} görüşmesinde yanıtladı",
    "A deleted user replied to your message in conversation {call}" : "Silinmiş bir kullanıcı {call} görüşmesinde iletinizi yanıtladı",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (konuk) {call} görüşmesindeki bir iletiyi yanıtladı",
    "A guest replied to your message in conversation {call}" : "Bir konuk {call} görüşmesinde iletinizi yanıtladı",
    "Reminder: You in private conversation {call}" : "Anımsatma: {call} özel görüşmesindesiniz",
    "Reminder: A deleted user in private conversation {call}" : "Anımsatma: Silinmiş bir kullanıcı {call} özel görüşmesinde",
    "Reminder: {user} in private conversation" : "Anımsatma: {user} özel görüşmede",
    "Reminder: You in conversation {call}" : "Anımsatma: {call} görüşmesindesiniz",
    "Reminder: {user} in conversation {call}" : "Anımsatma: {user}, {call} görüşmesinde",
    "Reminder: A deleted user in conversation {call}" : "Anımsatma: Silinmiş bir kullanıcı {call} görüşmesinde",
    "Reminder: {guest} (guest) in conversation {call}" : "Anımsatma: {guest} (konuk) {call} görüşmesinde",
    "Reminder: A guest in conversation {call}" : "Anımsatma: Bir konuk {call} görüşmesinde",
    "{user} reacted with {reaction} to your private message" : "{user}, kişisel iletinizi {reaction} ile yanıtladı",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user}, {call} görüşmesindeki iletinizi {reaction} ile yanıtladı",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Silinmiş bir kullanıcı {call} görüşmesindeki iletinizi {reaction} ile yanıtladı ",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (konuk), {call} görüşmesindeki iletinizi {reaction} ile yanıtladı",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Bir konuk, {call} görüşmesindeki iletinizi {reaction} ile yanıtladı",
    "{user} mentioned you in a private conversation" : "{user} özel bir görüşmede sizi andı",
    "{user} mentioned group {group} in conversation {call}" : "{user}, {call} görüşmesinde {group} grubunu andı",
    "{user} mentioned team {team} in conversation {call}" : "{user}, {call} görüşmesinde {team} takımını andı",
    "{user} mentioned everyone in conversation {call}" : "{user}, {call} görüşmesindeki herkesi andı",
    "{user} mentioned you in conversation {call}" : "{user}, {call} görüşmesinde sizi andı",
    "A deleted user mentioned group {group} in conversation {call}" : "Silinmiş bir kullanıcı, {call} görüşmesinde {group} grubunu andı",
    "A deleted user mentioned team {team} in conversation {call}" : "Silinmiş bir kullanıcı, {call} görüşmesinde {team} takımını andı",
    "A deleted user mentioned everyone in conversation {call}" : "Silinmiş bir kullanıcı, {call} görüşmesinde herkesi andı",
    "A deleted user mentioned you in conversation {call}" : "Silinmiş bir kullanıcı {call} görüşmesinde sizi andı",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (konuk), {call} görüşmesinde {group} grubunu andı",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (konuk), {call} görüşmesinde {team} takımını andı",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (konuk), {call} görüşmesindeki herkesi andı",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (konuk) {call} görüşmesinde sizi andı",
    "A guest mentioned group {group} in conversation {call}" : "Bir konuk, {call} görüşmesinde {group} grubunu andı",
    "A guest mentioned team {team} in conversation {call}" : "Bir konuk, {call} görüşmesinde {team} takımını andı",
    "A guest mentioned everyone in conversation {call}" : "Bir konuk, {call} görüşmesindeki herkesi andı",
    "A guest mentioned you in conversation {call}" : "Bir konuk {call} görüşmesinde sizi andı",
    "View message" : "İletiyi görüntüle",
    "Dismiss reminder" : "Anımsatmayı yok say",
    "View chat" : "Sohbeti görüntüle",
    "{user} invited you to a group conversation: {call}" : "{user} sizi bir grup görüşmesine davet etti: {call}",
    "Join call" : "Çağrıya katıl",
    "Answer call" : "Çağrıyı yanıtla",
    "{user} would like to talk with you" : "{user} sizinle görüşmek istiyor",
    "Call back" : "Geri ara",
    "You missed a call from {user}" : "{user} kullanıcısı sizi aramış",
    "Accept call" : "Çağrıyı kabul et",
    "Incoming phone call from {call}" : "{call} tarafından gelen telefon çağrısı",
    "You missed a phone call from {call}" : "{call} tarafından gelen bir telefon çağrısını yanıtlamadınız",
    "A group call has started in {call}" : "{call} içinde bir grup çağrısı başlatıldı",
    "You missed a group call in {call}" : "{call} grubu sizi aramış",
    "{email} is requesting the password to access {file}" : "{email}, {file} dosyasına erişme parolasını istiyor",
    "{email} tried to request the password to access {file}" : "{email}, {file} dosyasına erişme parolasını istemeyi denedi",
    "Someone is requesting the password to access {file}" : "Birisi {file} dosyasına erişme parolasını istiyor",
    "Someone tried to request the password to access {file}" : "Birisi {file} dosyasına erişme parolasını istemeyi denedi",
    "Open settings" : "Ayarları aç",
    "Hosted signaling server added" : "Barındırılan signaling sunucusu eklendi",
    "The hosted signaling server is now configured and will be used." : "Barındırılan signaling sunucusu yapılandırıldı ve kullanılmaya hazır.",
    "Hosted signaling server removed" : "Barındırılan signaling sunucusu silindi",
    "The hosted signaling server was removed and will not be used anymore." : "Barındırılan signaling sunucusu silindi ve kullanımdan kaldırıldı.",
    "Hosted signaling server changed" : "Barındırılan signaling sunucusu değiştirildi",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Barındırılan signaling sunucu hesabının \"{oldstatus}\" olan durumu \"{newstatus}\" olarak değiştirildi.",
    "pending" : "bekliyor",
    "active" : "etkin",
    "expired" : "geçerlilik süresi dolmuş",
    "blocked" : "engellenmiş",
    "error" : "sorun",
    "The certificate of {host} expires in {days} days" : "{host} sertifikasının geçerlilik süresi {days} gün içinde dolacak",
    "The certificate of {host} expired" : "{host} sertifikasının geçerlilik süresi doldu",
    "Contact via Talk" : "Konuş ile görüşün",
    "Open Talk" : "Konuş uygulamasını aç",
    "Default" : "Varsayılan",
    "Presentation" : "Sunum",
    "Voice room" : "Konuşma odası",
    "Webinar" : "İnternet sunumu",
    "Conversations" : "Görüşmeler",
    "Messages in current conversation" : "Geçerli görüşmedeki iletiler",
    "{user}" : "{user}",
    "Messages" : "İletiler",
    "{user} in {conversation}" : "{user}, {conversation} görüşmesinde",
    "Messages in other conversations" : "Diğer görüşmelerdeki iletiler",
    "One-to-one rooms always need to show the other users avatar" : "Bire bir odalarda diğer kullanıcının avatarı her zaman görüntülenmelidir",
    "Invalid emoji character" : "Emoji karakteri geçersiz",
    "Invalid background color" : "Arka plan rengi geçersiz",
    "Avatar image is not square" : "Avatar görseli kare değil",
    "Room {number}" : "{number}. oda",
    "Other" : "Diğer",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Deneme sunucusuna erişilemediğinden deneme isteği yapılamadı. Lütfen bir süre sonra yeniden deneyin.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Kopyanın kimliği doğrulanırken bir sorun çıktı. Belirtilen adres kullanılarak dışarıdan erişilemiyor olabilir. ",
    "Something unexpected happened." : "Beklenmedik bir sorun çıktı.",
    "The URL is invalid." : "Adres geçersiz.",
    "An HTTPS URL is required." : "Bir HTTPS adresi yazılması zorunludur.",
    "The email address is invalid." : "E-posta adresi geçersiz.",
    "The language is invalid." : "Dil geçersiz.",
    "The country is invalid." : "Ülke geçersiz.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Deneme isteği yapılırken bir sorun çıktı. Lütfen ayrıntılı bilgi almak için günlük kayıtlarına bakın.",
    "Too many requests are send from your servers address. Please try again later." : "Sunucunuzun adresinden çok fazla sayıda istekte bulunulmuş. Lütfen bir süre sonra yeniden deneyin.",
    "There is already a trial registered for this Nextcloud instance." : "Bu Nextcloud kopyası için zaten bir deneme kaydı var.",
    "Something unexpected happened. Please try again later." : "Beklenmedik bir sorun çıktı. Lütfen bir süre sonra yeniden deneyin.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Deneme sunucusu doğru davranmadığından deneme isteğinde bulunulamadı. Lütfen bir süre sonra yeniden deneyin.",
    "Trial requested but failed to get account information. Please check back later." : "Deneme isteğinde bulunuldu ancak hesap bilgileri alınamadı. Lütfen burayı bir süre sonra yeniden denetleyin.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Bu isteğin kimliği doğrulanırken bir sorun çıktı. Belirtilen adres kullanılarak dışarıdan erişilemiyor olabilir. ",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Deneme sunucusu doğru davranmadığından hesap bilgileri alınamadı. Lütfen bir süre sonra yeniden deneyin.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Hesap bilgileri alınırken bir sorun çıktı. Lütfen ayrıntılı bilgi almak için günlük kayıtlarına bakın.",
    "There is no such account registered." : "Böyle bir hesap bulunamadı.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Deneme sunucusuna erişilemediğinden hesap bilgileri alınamadı. Lütfen bir süre sonra yeniden deneyin.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Barındırılan signaling sunucusu hesabı silinemedi. Lütfen bir süre sonra yeniden deneyin.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Deneme sunucusu doğru davranmadığından hesap silinemedi. Lütfen bir süre sonra yeniden deneyin.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Hesap silinirken bir sorun çıktı. Lütfen ayrıntılı bilgi almak için günlük kayıtlarına bakın.",
    "Too many requests are sent from your servers address. Please try again later." : "Sunucunuzun adresinden çok fazla sayıda istekte bulunuldu. Lütfen bir süre sonra yeniden deneyin.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Deneme sunucusuna erişilemediğinden hesap silinemedi. Lütfen bir süre sonra yeniden deneyin.",
    "Note to self" : "Kendime not",
    "A place for your private notes, thoughts and ideas" : "Kişisel notlarınızı, düşüncelerinizi ve fikirlerinizi buraya yazabilirsiniz",
    "Transcript is AI generated and may contain mistakes" : "Yazıya dönüştürme işlemi yapay zeka ile yapılmıştır ve hatalar olabilir",
    "Summary is AI generated and may contain mistakes" : "Özet yapay zeka ile oluşturulmuştur ve hatalar olabilir",
    "Let's get started!" : "Başlayalım!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Konuş**, Nextcloud ekosistemiyle sorunsuz bir şekilde bütünleşen güvenli, özel barındırılan bir iletişim platformudur.\n\n#### Nextcloud Konuş Temel Özellikleri:\n\n* Özel ve grup sohbetlerinde sohbet etme ve ileti gönderme\n* Sesli ve görüntülü aramalar\n* Diğer Nextcloud uygulamalarıyla dosya paylaşımı ve bütünleştirme\n* Özelleştirilebilir görüşme ayarları, yönetim ve gizlilik denetimleri\n* İnternet, bilgisayar ve mobil (iOS ve Android)\n* Gizli ve güvenli iletişim\n\nAyrıntılı bilgi almak için [kullanıcı belgelerine](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html) bakın.",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Nextcloud Konuş Uygulamasına Hoş Geldiniz\n\nNextcloud Konuş, Nextcloud ile bütünleşik gizli ve güçlü bir iletişim uygulamasıdır. Kişisel veya grup görüşmelerinde sohbet edin, sesli ve görüntülü görüşmelerde işbirliği yapın, internet toplantıları ve etkinlikler düzenleyin, görüşmelerinizi gizli tutun ve diğer şeyleri yapın.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Zengin iletiler oluşturmak için yazıları biçimlendirin\n\nNextcloud Konuş uygulamasında iletilerinizi biçimlendirmek için Markdown sözdizimini kullanabilirsiniz. Örneğin, **koyu** veya *yatık* biçimlendirme uygulayın veya `yazıları kod olarak vurgulayın`. Hatta yazınızda tablolar oluşturabilir ve başlıklar ekleyebilirsiniz.\n\nBir yazım yanlışını düzeltmeniz veya biçimlendirmeyi değiştirmeniz mi gerekiyor? İleti menüsünde \"İletiyi düzenle\" üzerine tıklayarak iletinizi düzenleyin.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Dosyalar ve bağlantılar ekleyin\n\n\"+\" düğmesini kullanarak Nextcloud Merkez üzerinden dosyalar ekleyin. Dosyalar ve çeşitli Nextcloud uygulamalarından ögeler paylaşın. Bazı uygulamalar, örneğin Yazı uygulaması, etkileşimli pano bileşenlerini bile destekler.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Görüşmelerin akmasına izin verin: Kullanıcıları anın, iletilere tepki verin ve diğer şeyleri yapın\n\nGörüşmedeki herkesi %s kullanarak anabilir veya \"@\" yazıp listeden adlarını seçerek belirli katılımcıları anabilirsiniz.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "İletileri yanıtlayabilir, onları diğer sohbetlere ve kişilere iletebilir veya ileti içeriğini kopyalayabilirsiniz.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Akıllı Seçici ile daha fazlasını yapın\n\nİletilerinize çeşitli içerikler ekleyebileceğiniz akıllı seçiciyi açmak için yalnızca \"/\" yazın veya \"+\" menüsüne gidin. Akıllı seçiciyi Nextcloud uygulamalarından, GIF görsellerinden, harita konumlarından, yapay zeka tarafından oluşturulan içeriklerden ve çok daha fazlasından ögeler ekleyebilecek şekilde yapılandırabilirsiniz.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Görüşme ayarlarını yönetin\n\nGörüşme menüsünde, görüşmelerinizi yönetebileceğiniz çeşitli ayarlara erişebilirsiniz. Örneğin:\n* Görüşme bilgilerini düzenleyebilirsiniz\n* Bildirimleri yönetebilirsiniz\n* Çok sayıda yönetim kuralı uygulayabilirsiniz\n* Erişim izinlerini ve güvenliği yapılandırabilirsiniz\n* Botları etkinleştirebilirsiniz\n* ve diğer şeyleri yapabilirsiniz!",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Birleşik Arap Emirlikleri",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua ve Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Arnavutluk",
    "Armenia" : "Ermenistan",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Arjantin",
    "American Samoa" : "Amerikan Samoası",
    "Austria" : "Avusturya",
    "Australia" : "Avustralya",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Adaları",
    "Azerbaijan" : "Azerbaycan",
    "Bosnia and Herzegovina" : "Bosna ve Hersek",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladeş",
    "Belgium" : "Belçika",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaristan",
    "Bahrain" : "Bahreyn",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei Barış Ülkesi",
    "Bolivia, Plurinational State of" : "Bolivya Çok Uluslu Devleti",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius ve Saba",
    "Brazil" : "Brezilya",
    "Bahamas" : "Bahamalar",
    "Bhutan" : "Butan",
    "Bouvet Island" : "Bouvet Adası",
    "Botswana" : "Botswana",
    "Belarus" : "Beyaz Rusya",
    "Belize" : "Beliz",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Cocos (Keyling) Adaları",
    "Congo, the Democratic Republic of the" : "Kongo Demokratik Cumhuriyeti",
    "Central African Republic" : "Orta Afrika Cumhuriyeti",
    "Congo" : "Kongo",
    "Switzerland" : "İsviçre",
    "Côte d'Ivoire" : "Fildişi Sahili",
    "Cook Islands" : "Cook Adaları",
    "Chile" : "Şili",
    "Cameroon" : "Kamerun",
    "China" : "Çin",
    "Colombia" : "Kolombiya",
    "Costa Rica" : "Kosta Rika",
    "Cuba" : "Küba",
    "Cabo Verde" : "Yeşil Burun Adaları",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Christmas Adası",
    "Cyprus" : "Kıbrıs",
    "Czechia" : "Çekya",
    "Germany" : "Almanya",
    "Djibouti" : "Cibuti",
    "Denmark" : "Danimarka",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominik Cumhuriyeti",
    "Algeria" : "Cezayir",
    "Ecuador" : "Ekvator",
    "Estonia" : "Estonya",
    "Egypt" : "Mısır",
    "Western Sahara" : "Batı Sahra",
    "Eritrea" : "Eritre",
    "Spain" : "İspanya",
    "Ethiopia" : "Etiyopya",
    "Finland" : "Finlandiya",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Falkland Adaları (Malvinas)",
    "Micronesia, Federated States of" : "Mikronezya Birleşik Devletleri",
    "Faroe Islands" : "Faroe Adaları",
    "France" : "Fransa",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Büyük Britanya Birleşik Krallık ve Kuzey İrlanda",
    "Grenada" : "Grenada",
    "Georgia" : "Gürcistan",
    "French Guiana" : "Fransız Guyanası",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Gine",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekvator Ginesi",
    "Greece" : "Yunanistan",
    "South Georgia and the South Sandwich Islands" : "Güney Georgia ve Güney Sandwich Adaları",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Gine-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard Adası ve McDonald Adaları",
    "Honduras" : "Honduras",
    "Croatia" : "Hırvatistan",
    "Haiti" : "Haiti",
    "Hungary" : "Macaristan",
    "Indonesia" : "Endonezya",
    "Ireland" : "İrlanda",
    "Israel" : "İsrail",
    "Isle of Man" : "Man Adası",
    "India" : "Hindistan",
    "British Indian Ocean Territory" : "Britanya Hint Okyanusu Toprakları",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "İran İslam Cumhuriyeti",
    "Iceland" : "İzlanda",
    "Italy" : "İtalya",
    "Jersey" : "Jersey Adası",
    "Jamaica" : "Jamaika",
    "Jordan" : "Ürdün",
    "Japan" : "Japonya",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kırgızistan",
    "Cambodia" : "Kamboçya",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komorlar",
    "Saint Kitts and Nevis" : "Saint Kitts ve Nevis",
    "Korea, Democratic People's Republic of" : "Kuzey Kore",
    "Korea, Republic of" : "Güney Kore",
    "Kuwait" : "Kuveyt",
    "Cayman Islands" : "Cayman Adaları",
    "Kazakhstan" : "Kazakistan",
    "Lao People's Democratic Republic" : "Laos Demokratik Halk Cumhuriyeti",
    "Lebanon" : "Lübnan",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Lihtenştayn",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberya",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litvanya",
    "Luxembourg" : "Lüksemburg",
    "Latvia" : "Letonya",
    "Libya" : "Libya",
    "Morocco" : "Fas",
    "Monaco" : "Monako",
    "Moldova, Republic of" : "Moldova Cumhuriyeti",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (Fransız Bölümü)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshall Adaları",
    "North Macedonia" : "Kuzey Makedonya",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Moğolistan",
    "Macao" : "Makau",
    "Northern Mariana Islands" : "Kuzey Mariana Adaları",
    "Martinique" : "Martinik",
    "Mauritania" : "Moritanya",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldivler",
    "Malawi" : "Malawi",
    "Mexico" : "Meksika",
    "Malaysia" : "Malezya",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibya",
    "New Caledonia" : "Yeni Kaledonya",
    "Niger" : "Nijer",
    "Norfolk Island" : "Norfolk Adası",
    "Nigeria" : "Nijerya",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Hollanda",
    "Norway" : "Norveç",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Yeni Zelanda",
    "Oman" : "Umman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Fransız Polinezyası",
    "Papua New Guinea" : "Papua Yeni Gine",
    "Philippines" : "Filipinler",
    "Pakistan" : "Pakistan",
    "Poland" : "Polonya",
    "Saint Pierre and Miquelon" : "Saint Pierre ve Miquelon",
    "Pitcairn" : "Pitcairn Adaları",
    "Puerto Rico" : "Porto Riko",
    "Palestine, State of" : "Filistin Devleti",
    "Portugal" : "Portekiz",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Romanya",
    "Serbia" : "Sırbistan",
    "Russian Federation" : "Rusya Federasyonu",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Suudi Arabistan",
    "Solomon Islands" : "Solomon Adaları",
    "Seychelles" : "Seyşeller",
    "Sudan" : "Sudan",
    "Sweden" : "İsveç",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension ve Tristan da Cunha",
    "Slovenia" : "Slovenya",
    "Svalbard and Jan Mayen" : "Svalbard ve Jan Mayen",
    "Slovakia" : "Slovakya",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somali",
    "Suriname" : "Surinam",
    "South Sudan" : "Güney Sudan",
    "Sao Tome and Principe" : "Sao Tome ve Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Hollanda Bölümü)",
    "Syrian Arab Republic" : "Suriye Arap Cumhuriyeti",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Turks ve Caicos Adaları",
    "Chad" : "Çad",
    "French Southern Territories" : "Fransız Güney Toprakları",
    "Togo" : "Togo",
    "Thailand" : "Tayland",
    "Tajikistan" : "Tacikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Türkmenistan",
    "Tunisia" : "Tunus",
    "Tonga" : "Tonga",
    "Turkey" : "Türkiye",
    "Trinidad and Tobago" : "Trinidad ve Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Tayvan, Çin Eyaleti",
    "Tanzania, United Republic of" : "Tanzanya Birleşik Cumhuriyeti",
    "Ukraine" : "Ukrayna",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Birleşik Devletler Küçük Dış Adaları",
    "United States of America" : "Amerika Birleşik Devletleri",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Özbekistan",
    "Holy See" : "Vatikan",
    "Saint Vincent and the Grenadines" : "Saint Vincent ve Grenadinler",
    "Venezuela, Bolivarian Republic of" : "Venezuela Bolivarcı Cumhuriyeti",
    "Virgin Islands, British" : "Virgin Adaları, Britanya",
    "Virgin Islands, U.S." : "Virgin Adaları, Birleşik Devletler",
    "Viet Nam" : "Viet Nam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis ve Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Güney Afrika",
    "Zambia" : "Zambiya",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Arka plan bulanıklaştırması",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "WASM yükleme desteği denetlenemedi. Lütfen site sunucunuzun `.wasm` dosyalarını sunup sunmadığını el ile denetleyin.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Site sunucunuz `.wasm` dosyalarını aktaracak şekilde yapılandırılmamış. Bu sık karşılaşılan bir Nginx yapılandırma sorunudur. Arka plan bulanıklaştırması için `.wasm` dosyalarını da aktaracak ek bir ayar yapılması gereklidir. Kullandığınız Nginx yapılandırmasını belgeler bölümünde bulunan önerilen yapılandırma dosyası ile karşılaştırın.",
    "Talk configuration values" : "Konuş yapılandırma değerleri",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Yalnızca sistem zamanlanmış görevi ile bir çağrı süresi dayatılabilir. Lütfen sistem zamanlanmış görevini açın ya da `max_call_duration` yapılandırmasını kaldırın.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Küçük `max_call_duration` değerleri (şu anda %d olarak ayarlanmış) teknik sınırlamalar nedeniyle zorunlu kılınamaz. Arka plan görevi yalnızca her 5 dakikada bir yürütülür. Buradaki riski kabul ederek kullanın.",
    "Federation" : "Birleşim",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Konuş birleştirme özelliği açıldığında \"memcache.locking\" yapılandırmasının ayarlanması önemle önerilir.",
    "High-performance backend" : "Yüksek başarımlı arka yüz",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Yüksek başarımlı arka yüz yapılandırılmamış - Yüksek başarımlı arka yüz olmadan Nextcloud Konuş yalnızca çok küçük çağrılar için çalışabilir (en fazla 2-3 katılımcı). Birden fazla katılımcının olduğu çağrıların sorunsuz çalışmasını sağlamak için lütfen yüksek başarımlı arka yüzü ayarlayın.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Yüksek başarımlı arka yüz, \"conversation_cluster\" kipini çalıştırma özelliği kapatıldı ve yaklaşan sürümde artık desteklenmeyecek. Yüksek başarımlı arka yüz artık gerçek kümelemeyi destekliyor ve bunun yerine kullanılmalı.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Birden fazla yüksek başarımlı arka yüz tanımlama özelliği kapatıldı ve yaklaşan sürümde artık desteklenmeyecek. Bunun yerine, kümelenmiş sinyal sunucularıyla birlikte bir yük dengeleyici kurulmalı ve Konuş uygulaması ayarlarından yapılandırılmalıdır.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Kullanılan %1$s algoritması için kaydedilmiş herkese açık anahtar, kaydedilmiş kişisel anahtarla eşleşmiyor. Sorunu çözmek için %2$s işlemini yürütün.",
    "High-performance backend not configured correctly. Run %s for details." : "Yüksek başarımlı arka yüz doğru yapılandırılmamış. Ayrıntılı bilgi almak için %s komutunu yürütün.",
    "High-performance backend not configured correctly" : "Yüksek başarımlı arka yüz doğru yapılandırılmamış",
    "Error: Cannot connect to server" : "Hata: Sunucu ile bağlantı kurulamadı",
    "Error: Server did not respond with proper JSON" : "Hata: Sunucunun JSON yanıtı geçersiz",
    "Error: Certificate expired" : "Hata: Sertifikanın geçerlilik süresi dolmuş",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Hata: Nextcloud sunucusunun ve yüksek başarımlı arka yüz sunucusunun sistem saatleri aynı değil. Lütfen her iki sunucunun da bir zaman sunucusuna bağlı olduğundan emin olun ya da saatlerini el ile eşitleyin.",
    "Could not get version" : "Sürüm alınamadı",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Hata: Çalışan sürüm: {version}. Bu Konuş sürümüyle uyumlu olması için sunucunun güncellenmesi gerekiyor",
    "Error: Server responded with: {error}" : "Hata: Sunucu yanıtı: {error}",
    "Error: Unknown error occurred" : "Hata: Bilinmeyen bir sorun çıktı",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Uyarı: Çalışan sürüm: {version}; Sunucu bu Konuş sürümünün tüm özelliklerini desteklemiyor. Eksik özellikler: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Nextcloud Konuş yüksek başarımlı bir arka yüzde çalıştırılırken, bir bellek ön belleği yapılandırmanız önemle önerilir.",
    "Client Push" : "Client Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Client Push kurulmuş. Talk bildirimlerinin dakikliği iyileştiriliyor.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} kurulmamış. Talk bildirimlerinde gecikmeler olabilir.",
    "Recording backend" : "Kayıt arka yüzü",
    "Using the recording backend requires a High-performance backend." : "Kayıt arka yüzünün kullanılabilmesi için bir yüksek başarımlı arka yüz gereklidir.",
    "No recording backend configured" : "Herhangi bir kayıt arka yüzü yapılandırılmamış",
    "SIP configuration" : "SIP yapılandırması",
    "Using the SIP functionality requires a High-performance backend." : "SIP özelliğinin kullanılabilmesi için bir yüksek başarımlı arka yüz gereklidir.",
    "No SIP backend configured" : "Herhangi bir SIP arka yüzü yapılandırılmamış.",
    "Invalid date, date format must be YYYY-MM-DD" : "Tarih geçersiz. Tarih biçimi YYYY-AA-GG olmalıdır",
    "Conversation not found" : "Görüşme bulunamadı",
    "Path is already shared with this conversation" : "Yol bu görüşme ile zaten paylaşılmış",
    "Chat, video & audio-conferencing using WebRTC" : "WebRTC kullanarak yazılı, sesli ve görüntülü görüşmeler yapabilirsiniz",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "WebRTC ile sohbet, görüntülü ve sesli görüşme\n\n* 💬 **Sohbet** Nextcloud Konuş üzerinde, Nextcloud Dosyalar uygulamanızdan veya yerel aygıtınızdan dosya paylaşmanızı veya yüklemenizi ve diğer katılımcıları anmanızı sağlayan basit bir yazı sohbeti uygulaması bulunur.\n* 👥 **Özel, gruba, herkese açık ve şifre korumalı çağrılar!** Bir kişiyi ya da tüm grubu davet edin veya bir bağlantı ile herkesin çağrıya katılmasını sağlayın.\n* 🌐 **Birleşik sohbetler** Diğer Nextcloud sunucularındaki kullanıcılarla sohbet edin\n* 💻 **Ekran paylaşımı!** Ekranınızı görüşmenizin katılımcılarıyla paylaşın.\n* 🚀 **Dosyalar, Takvim, Kullanıcı durumu, Pano, Akış, Haritalar, Akıllı seçici, Kişiler, Deck ve diğer Nextcloud uygulamalarıyla bütünleşik**.\n* 🌉 **Diğer sohbet çözümleriyle eşitleme** [Matterbridge](https://github.com/42wim/matterbridge/) Konuş uygulaması ile bütünleştirildiğinde, diğer birçok sohbet çözümünü Nextcloud Konuş ile kolayca eşitleyebilirsiniz.",
    "Leave call" : "Çağrıdan ayrıl",
    "Navigating away from the page will leave the call in {conversation}" : "Sayfadan ayrılırsanız {conversation} çağrısından çıkacaksınız",
    "Stay in call" : "Çağrıda kal",
    "Error occurred when getting the conversation information" : "Görüşme bilgileri alınırken sorun çıktı",
    "Discuss this file" : "Bu dosya hakkında görüş",
    "Share this file with others to discuss it" : "Bu dosyayı, hakkında görüşmek için başkaları ile paylaş",
    "Share this file" : "Bu dosyayı paylaş",
    "Join conversation" : "Görüşmeye katıl",
    "This conversation is password-protected." : "Bu görüşme parola ile korunmuş.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "IP adresinizden yapılan birden çok geçersiz parola yazma girişimi algılandı. Bu nedenle sonraki denemeniz 30 saniye süreyle engellendi.",
    "The password is wrong. Try again." : "Parola yanlış. Yeniden deneyin.",
    "Password" : "Parola",
    "Submit" : "Gönder",
    "Error requesting the password." : "Parola istenirken sorun çıktı.",
    "Request password" : "Parola istensin",
    "This conversation has ended" : "Bu görüşme sona ermiş",
    "Error occurred when joining the conversation" : "Görüşmeye katılmakta sorun çıktı",
    "Close Talk sidebar" : "Konuş kenar çubuğunu kapat",
    "Open Talk sidebar" : "Konuş kenar çubuğunu aç",
    "Everyone" : "Herkes",
    "Users and moderators" : "Kullanıcılar ve sorumlular",
    "Moderators only" : "Yalnızca sorumlular",
    "Disable calls" : "Çağrıları kapat",
    "Save changes" : "Değişiklikleri Kaydet",
    "Saving …" : "Kaydediliyor …",
    "Saved!" : "Kaydedildi!",
    "Limit to groups" : "Şu gruplarla sınırla",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "En az bir grup seçildiğinde, yalnızca belirtilen gruplardaki kişiler görüşmelere katılabilir.",
    "Guests can still join public conversations." : "Konuklar hala herkese açık görüşmelere katılabilir.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Artık Konuş uygulamasını kullanamayan kullanıcılar, daha önce katıldıkları görüşmelerde katılımcı olarak görüntülenmeyi sürdürecek ve sohbet iletileri de korunacak.",
    "Limit using Talk" : "Konuş uygulamasının kullanımı sınırlansın",
    "Limit creating a public and group conversation" : "Herkese açık ve grup görüşmesi oluşturma sınırlansın",
    "Limit creating conversations" : "Görüşme oluşturma sınırlansın",
    "Limit starting a call" : "Bir çağrı başlatma sınırlansın",
    "Limit starting calls" : "Çağrı başlatma sınırlansın",
    "When a call has started, everyone with access to the conversation can join the call." : "Bir çağrı yapıldığında, görüşmeye erişimi olan herkes çağrıya katılabilir.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Bu sunucuda şu botlar kurulu. Belgelerde, sunucunuzda kullanmak için {linkstart1}kendi botunuzu nasıl oluşturacağınız{linkend} ya da{linkstart2}bot listesi{linkend} hakkında ayrıntılı bilgi bulabilirsiniz.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Bu sunucuda herhangi bir bot kurulu değil. Belgelerde, sunucunuzda kullanmak için {linkstart1}kendi botunuzu nasıl oluşturacağınız{linkend} ya da{linkstart2}bot listesi{linkend} hakkında ayrıntılı bilgi bulabilirsiniz.",
    "Description is not provided" : "Açıklama yazılmamış",
    "Locked for moderators" : "Sorumlular için kilitli",
    "Enabled" : "Kullanılıyor",
    "Disabled" : "Kullanılmıyor",
    "Bots settings" : "Bot ayarları",
    "State" : "Durum",
    "Name" : "Ad",
    "Last error" : "Son hata",
    "Total errors count" : "Toplam hata sayısı",
    "Find more bots" : "Başka botlar bul",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Güvenilen sunucular  {linkstart}Paylaşım ayarları{linkend} bölümünden yapılandırılabilir.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Birleşik sohbetler ve aramalar zaten çalışıyor. Ek dosyaların işlenmesi gelecek sürümlerde eklenecek.",
    "Enable Federation in Talk app" : "Konuş uygulamasında birlik kullanılsın",
    "Permissions" : "İzinler",
    "Allow users to be invited to federated conversations" : "Kullanıcılar birleşik görüşmelere davet edilebilsin",
    "Allow users to invite federated users into conversation" : "Kulanıcılar görüşmelere birleşik kullanıcıları davet edebilsin",
    "Only allow to federate with trusted servers" : "Yalnızca güvenilen sunucular ile birleşik çalışılabilsin",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "En az bir grup seçildiğinde, yalnızca belirtilen gruplardaki kişiler görüşmelere birleşik kullanıcıları davet edebilir.",
    "Groups allowed to invite federated users" : "Birleşik kullanıcıları davet edebilecek gruplar",
    "Select groups …" : "Grupları seçin…",
    "All messages" : "Tüm iletiler",
    "@-mentions only" : "Yalnızca @-anmaları",
    "Off" : "Kapalı",
    "General settings" : "Genel ayarlar",
    "Default notification settings" : "Varsayılan bildirim ayarları",
    "Default group notification" : "Varsayılan grup bildirimi",
    "Default group notification for new groups" : "Yeni gruplar için varsayılan grup bildirimi",
    "Integration into other apps" : "Diğer uygulamalar ile bütünleştirme",
    "Allow conversations on files" : "Dosyalar üzerine görüşme yapılabilsin",
    "Allow conversations on public shares for files" : "Herkese açık paylaşımlardaki dosyalar üzerine görüşme yapılabilsin",
    "End-to-end encrypted calls" : "Uçtan uca şifrelenmiş çağrılar",
    "Enable encryption" : "Şifreleme kullanılsın",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Yapılandırılmış bir SIP köprüsü ile uçtan uca şifrelenmiş çağrılar için, yüksek başarımlı arka yüz ve SIP köprüsünün daha yeni bir sürümü gerekir.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Şu anda mobil istemcilerde uçtan uca şifrelenmiş çağrılar desteklenmiyor.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Yukarıdaki düğmeye tıklayarak formdaki bilgileri Struktur AG tarafına göndermiş olacaksınız. Diğer bilgileri {linkstart}spreed.eu{linkend} üzerinde bulabilirsiniz.",
    "Pending" : "Bekleyen",
    "Error" : "Hata",
    "Blocked" : "Engellenmiş",
    "Active" : "Etkin",
    "Expired" : "Geçerlilik süresi dolmuş",
    "Never" : "Yok",
    "The trial could not be requested. Please try again later." : "Deneme isteği yapılamadı. Lütfen bir süre sonra yeniden deneyin.",
    "The account could not be deleted. Please try again later." : "Hesap silinemedi. Lütfen bir süre sonra yeniden deneyin.",
    "Hosted High-performance backend" : "Barındırılan yüksek başarımlı arka yüz",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "İş ortağımız Struktur AG, barındırılan bir signaling sunucusu isteğinde bulunabileceğiniz bir hizmet sunuyor. Bunun için aşağıdaki formu doldurmanız yeterlidir. Nextcloud kopyanız istekte bulunur. Sunucu kurulduktan sonra kimlik doğrulama bilgileri otomatik olarak doldurulur. Bu işlem var olan signaling sunucusu ayarlarının üzerine yazar.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Yüksek başarımlı arka uç hesabınızda STUN ve/veya TURN özelliği bulunuyorsa, ayarlar buna göre güncellenir.",
    "URL of this Nextcloud instance" : "Bu Nextcloud kopyasının adresi",
    "Full name of the user requesting the trial" : "Deneme isteğinde bulunan kullanıcının tam adı",
    "Email of the user" : "Kullanıcının e-posta adresi",
    "Language" : "Dil",
    "Country" : "Ülke",
    "Request signaling server trial" : "Signaling sunucusu deneme isteği",
    "You can see the current status of your hosted signaling server in the following table." : "Barındırılan signaling sunucunuzun güncel durumunu aşağıdaki tabloda görebilirsiniz.",
    "Status" : "Durum",
    "Created at" : "Oluşturulma",
    "Expires at" : "Geçerlilik süresi sonu",
    "Limits" : "Sınırlar",
    "STUN included" : "STUN var",
    "Yes" : "Evet",
    "No" : "Hayır",
    "TURN included" : "TURN var",
    "Delete the signaling server account" : "Signaling sunucu hesabını sil",
    "_%n user_::_%n users_" : ["%n kullanıcı","%n kullanıcı"],
    "Installed version: {version}" : "Kurulu sürüm: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Nextcloud Konuş ile diğer hizmetleri bağlamak için Matterbridge kurabilirsiniz. Ayrıntılı bilgi almak için Matterbridge {linkstart1}GitHub sayfasına{linkend} bakabilirsiniz. Uygulamanın indirilip kurulması biraz zaman alabilir. İşlem zaman aşımına uğrarsa {linkstart2}Nextcloud uygulama mağazasından{linkend} el ile kurun.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Matterbridge yürütülebilir dosyasının izinleri doğru değil. Lütfen Matterbridge yürütülebilir dosyasının sahibinin doğru kullanıcı olduğundan ve yürütülebilir olduğundan emin olun. Bu dosya \"/…/nextcloud/apps/talk_matterbridge/bin/\" klasöründe bulunur.",
    "Matterbridge binary was not found or couldn't be executed." : "Matterridge yürütülebilir dosyası bulunamadı ya da yürütülemiyor.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Matterbridge uygulamasının yolunu yapılandırma bölümünden el ile de ayarlayabilirsiniz. Ayrıntılı bilgi almak için {linkstart}Matterbridge bütünleştirme belgelerine{linkend} bakabilirsiniz.",
    "Downloading …" : "İndiriliyor…",
    "Install Talk Matterbridge" : "Konuş Matterbridge kur",
    "An error occurred while installing the Matterbridge app" : "Matterbridge uygulaması kurulurken bir sorun çıktı",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Konuş Matterbridge kurulurken bir sorun çıktı. Lütfen el ile kurun",
    "Failed to execute Matterbridge binary." : "Matterbridge uygulaması çalıştırılamadı.",
    "Matterbridge integration" : "Matterbridge bütünleştirmesi",
    "Enable Matterbridge integration" : "Matterbridge bütünleştirmesi kullanılsın",
    "Status: Checking connection" : "Durum: Bağlantı denetleniyor",
    "OK: Running version: {version}" : "Tamam: Çalışan sürüm: {version}",
    "Error: Server seems to be a Signaling server" : "Hata: Sunucu bir signaling sunucusu gibi görünüyor",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Hata: Nextcloud sunucusunun ve kayıt arka yüzü sunucusunun sistem saatleri aynı değil. Lütfen her iki sunucunun da bir zaman sunucusuna bağlı olduğundan emin olun ya da saatlerini el ile eşitleyin.",
    "Recording backend URL" : "Kayıt arka yüzü adresi",
    "Validate SSL certificate" : "SSL sertifikasını doğrula",
    "Delete this server" : "Bu sunucuyu sil",
    "Test this server" : "Bu sunucuyu sına",
    "Disabled for all calls" : "Tüm çağrılar için kapalı",
    "Enabled for all calls" : "Tüm çağrılar için açık",
    "Configurable on conversation level by moderators" : "Sorumlular tarafından görüşme düzeyinde yapılandırılabilir",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "\"upload_max_filesize\" or \"post_max_size\" PHP ayarı en fazla {maxUpload} boyutundaki dosyaların yüklenmesine izin veriyor.",
    "Recording backend settings saved" : "Kayıt arka yüzü ayarları kaydedildi",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Sorumlular görüşme düzeyinde kayıt alma rızasını açabilir. Bu görüşmedeki çağrılara katılmadan önce her kullanıcıdan kayıt alma rızası istenir.",
    "The consent to be recorded will be required for each participant before joining every call." : "Her katılımcıdan çağrılara katılmadan önce kayıt alma rızası istenir. ",
    "The consent to be recorded is not required." : "Kayıt alma rızası istenmez.",
    "Recording backend configuration is only possible with a High-performance backend." : "Kayıt arka yüzü yapılandırması yalnızca yüksek başarımlı arka yüz ile kullanılabilir.",
    "Add a new recording backend server" : "Yeni bir kayıt arka yüzü sunucusu ekle",
    "Shared secret" : "Paylaşılan parola",
    "Recording consent" : "Kayıt alma rızası",
    "Recording transcription" : "Kaydı yazıya dönüştürme",
    "Automatically transcribe call recordings with a transcription provider" : "Bir yazıya dönüştürme hizmeti ile çağrı kayıtlarını otomatik olarak yazıya dönüştürün",
    "Automatically summarize call recordings with transcription and summary providers" : "Yazıya dönüştürme ve özetleme hizmetleri ile çağrı kayıtlarını otomatik olarak özetleyin",
    "SIP configuration saved!" : "SIP yapılandırması kaydedildi!",
    "SIP configuration is only possible with a High-performance backend." : "SIP yapılandırması yalnızca yüksek başarımlı arka yüz ile kullanılabilir.",
    "Enable SIP Dial-out option" : "SIP çevirme seçeneği kullanılsın",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Signalling sunucusunun desteklenen SIP çevirme özelliğine güncellenmesi gerekiyor.",
    "Do not show SIP Dial-out caller number" : "SIP giden arama numarası görüntülenmesin",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Alıcıyı aramak için anonim numara \"bilinmiyor\" veya \"gizli numara\" olarak görünmeli",
    "Dial-out number" : "Giden arama numarası",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Giden aramalar için varsayılan arayan numara olarak kullanılacak E164 biçiminde numara",
    "Dial-out prefix" : "Giden arama ön eki",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Giden aramalar için yapılandırılmış kullanıcı numarası ön eki (varsayılan `+`)",
    "Restrict SIP configuration" : "SIP yapılandırması kısıtlansın",
    "Enable SIP configuration" : "SIP yapılandırması kullanılsın",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Yalnızca aşağıdaki grupların kullanıcıları sorumlu oldukları görüşmelerde SIP özelliğini açabilir",
    "Phone number (Country)" : "Telefon numarası (Ülke)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Bu bilgiler davet e-postalarında gönderilir ve ayrıca kenar çubuğunda tüm katılımcılara görüntülenir.",
    "Nextcloud base URL" : "Temel Nextcloud adresi",
    "Talk Backend URL" : "Konuş arka yüzü adresi",
    "WebSocket URL" : "WebSocket adresi",
    "Available features" : "Kullanılabilecek özellikler",
    "Error: Websocket connection failed" : "Hata: Websocket bağlantısı kurulamadı",
    "Error code" : "Hata kodu",
    "Error message" : "Hata iletisi",
    "Error: Websocket connection failed. Check browser console" : "Hata: Websocket bağlantısı kurulamadı. Tarayıcı konsoluna bakın",
    "High-performance backend URL" : "Yüksek başarımlı arka yüz adresi",
    "Missing High-performance backend warning hidden" : "Yüksek başarımlı arka yüz eksik uyarısı gizlendi",
    "High-performance backend settings saved" : "Yüksek başarımlı arka yüz ayarları kaydedildi",
    "Nextcloud Talk setup not complete" : "Nextcloud Konuş kurulumu tamamlanmamış",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Yüksek başarımlı arka yüz olmadan iki kişiden fazla katılımcının olduğu görüşmelerde, katılımcıların büyük olasılıkla bağlantı sorunları yaşayacağını ve katılımcı aygıtlarında yüksek yük oluşacağını unutmayın.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Birden fazla katılımcının olduğu görüşmelerin sorunsuz bir şekilde yapılabilmesi için yüksek başarımlı arka yüz kurun.",
    "Nextcloud portal" : "Nextcloud sitesi",
    "Quick installation guide" : "Hızlı kurulum rehberi",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Birden fazla katılımcının olduğu aramalar ve görüşmeler için yüksek başarımlı arka yüz olmadan, tüm katılımcılar her katılımcı için kendi videolarını ayrı ayrı yüklemek zorunda kalır. Bu da büyük olasılıkla bağlantı sorunlarına ve katılımcı aygıtlarında yüksek yüke neden olur.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Nextcloud Konuş uygulamasını yüksek başarımlı bir arka yüz ile kullanırken dağıtılmış bir ön bellek kurmanız önemle önerilir.",
    "Add High-performance backend server" : "Yüksek başarımlı arka yüz sunucusu ekle",
    "Warn about connectivity issues in calls with more than 2 participants" : "2 kişiden fazla katılımcısı olan çağrılarda bağlantı sorunları uyarısı görüntülensin",
    "STUN server URL" : "STUN sunucusunun adresi",
    "The server address is invalid" : "Sunucu adresi geçersiz",
    "STUN settings saved" : "STUN ayarları kaydedildi",
    "STUN servers" : "STUN sunucuları",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN sunucusu bir yönelticinin arkasındaki katılımcının herkese açık adresinin belirlenmesinde kullanılır.",
    "Add a new STUN server" : "Yeni STUN sunucusu ekle",
    "{schema} scheme must be used with a domain" : "{schema} şeması bir etki alanı ile birlikte kullanılmalıdır",
    "{option1} and {option2}" : "{option1} ve {option2}",
    "{option} only" : "yalnızca {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "Tamam: TURN sunucusu tarafından çalışan ICE adayları bildirildi",
    "Error: No working ICE candidates returned by the TURN server" : "Sorun: TURN sunucusu tarafından çalışan bir ICE adayı bildirilmedi",
    "Testing whether the TURN server returns ICE candidates" : "TURN sunucusunun ICE adaylarını bildirip bildirmediği sınanıyor",
    "TURN server schemes" : "TURN sunucu şemaları",
    "TURN server URL" : "TURN sunucusunun adresi",
    "TURN server secret" : "TURN sunucu parolası",
    "TURN server protocols" : "TURN sunucu iletişim kuralları",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN sunucusu bir güvenlik duvarı arkasındaki katılımcıların bağlanabilmesi için kullanılan bir vekil sunucudur. Bazı kullanıcılar diğerlerine bağlanamıyorsa genellikle bir TURN sunucusunun kullanılması gerekir. Kurulum bilgileri için {linkstart}bu belgeye{linkend} bakabilirsiniz.",
    "TURN settings saved" : "TURN ayarları kaydedildi",
    "TURN servers" : "TURN sunucuları",
    "Add a new TURN server" : "Yeni TURN sunucusu ekle",
    "Failed" : "Tamamlanamadı",
    "OK" : "Tamamlandı",
    "Checking …" : "Denetleniyor…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Tamamlanamadı: WebAssembly kullanımdan kaldırılmış ya da bu tarayıcıda desteklenmiyor. Denetlemek için WebAssembly eklentisini kullanıma alın ya da destekleyen bir tarayıcı kullanın.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Tamamlanamadı: Site sunucusu \".wasm\" ve \".tflite\" dosyalarını düzgün şekilde geri döndürmedi. Lütfen Konuş belgelerinde \"sistem gereksinimleri\" bölümüne bakın.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "Tamamlandı: Site sunucusu \".wasm\" ve \".tflite\" dosyalarını düzgün şekilde geri döndürdü.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Görünüşe göre PHP ile Apache yapılandırması uyumlu değil. Lütfen PHP kurulumunun yalnızca MPM_PREFORK modülü ile PHP-FPM kurulumunun yalnızca MPM_EVENT modülü ile kullanılabileceğini unutmayın.",
    "Web server setup checks" : "Site sunucusu kurulumu denetimleri",
    "Files required for virtual background can be loaded" : "Arka plan için kullanılacak dosyalar yüklenebilir",
    "Federated user" : "Birleşik kullanıcı",
    "Assign participants to rooms" : "Katılımcıları odalara dağıt",
    "Configure breakout rooms" : "Çalışma odaları yapılandırması",
    "Number of breakout rooms" : "Çalışma odası sayısı",
    "You can create from 1 to 20 breakout rooms." : "1 ile 20 arasında çalışma odası oluşturabilirsiniz.",
    "Assignment method" : "Atama yöntemi",
    "Automatically assign participants" : "Katılımcılar otomatik olarak dağıtılsın",
    "Manually assign participants" : "Katılımcılar el ile dağıtılsın",
    "Allow participants to choose" : "Katılımcılar oda seçebilsin",
    "Create rooms" : "Odaları oluştur",
    "Confirm" : "Onayla",
    "Create breakout rooms" : "Çalışma odaları oluştur",
    "Reset" : "Sıfırla",
    "Delete breakout rooms" : "Çalışma odalarını sil",
    "Room {roomNumber}" : "{roomNumber}. oda",
    "Current breakout rooms and settings will be lost" : "Geçerli çalışma odaları ve ayarları kaybolacak",
    "Cancel" : "İptal",
    "Unassigned participants" : "Dağıtılmamış katılımcılar",
    "Back" : "Geri",
    "Assign" : "Ata",
    "Add participant \"{user}\"" : "\"{user}\" katılımcısını ekle",
    "Now" : "Şimdi",
    "Invalid calendar selected" : "Seçilen takvim geçersiz",
    "Invalid start time selected" : "Seçilen başlangıç zamanı geçersiz",
    "Invalid end time selected" : "Seçilen bitiş zamanı geçersiz",
    "Unknown error occurred" : "Bilinmeyen bir sorun çıktı",
    "Sending no invitations" : "Herhangi bir davet gönderilemedi",
    "{participant0} will receive an invitation" : "{participant0} için davet gönderilecek",
    "{participant0} and {participant1} will receive invitations" : "{participant0} ve {participant1} için davet gönderilecek",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} ve %n diğer kişi için davet gönderilecek","{participant0}, {participant1} ve %n diğer kişi için davet gönderilecek"],
    "Invite {user}" : "{user} kullanıcısını davet et",
    "Invite all users and emails in this conversation" : "Bu görüşmedeki tüm kullanıcıları ve e-postaları davet et",
    "Meeting created" : "Toplantı oluşturuldu",
    "Upcoming meetings" : "Yaklaşan toplantılar",
    "Loading …" : "Yükleniyor…",
    "No upcoming meetings" : "Yaklaşan bir toplantı yok",
    "Schedule a meeting" : "Bir toplantı zamanla",
    "Meeting title" : "Toplantı başlığı",
    "From" : "Başlangıç",
    "To" : "Bitiş",
    "Calendar" : "Takvim",
    "Attendees" : "Katılanlar",
    "No other participants to send invitations to." : "Davet gönderilecek başka bir katılımcı yok.",
    "Add attendees" : "Katılımcılar ekle",
    "Save" : "Kaydet",
    "Search participants" : "Katılımcı arama",
    "No results" : "Herhangi bir sonuç bulunamadı",
    "Done" : "Tamam",
    "Disable live transcription" : "Canlı yazıya dönüştürmeyi kapat",
    "Enable live transcription (generated by AI)" : "Canlı yazıya dönüştürmeyi aç (yapar zeka ile)",
    "Disable live translation" : "Canlı çeviriyi kapat",
    "Enable live translation (generated by AI)" : "Canlı çeviriyi aç (yapay zeka ile)",
    "Original language: {languageName}" : "Özgün dil: {languageName}",
    "Translated language" : "Çevrilmiş dil",
    "Translated language: {languageName}" : "Çevrilmiş dil: {languageName}",
    "Raise hand" : "El kaldır",
    "Raise hand (R)" : "El kaldır (R)",
    "Lower hand" : "Eli indir",
    "Lower hand (R)" : "Eli indir (R)",
    "Exit full screen (F)" : "Tam ekrandan çık (F)",
    "Full screen (F)" : "Tam ekran (F)",
    "Speaker view" : "Konuşmacı görünümü",
    "Grid view" : "Tablo görünümü",
    "Error when trying to load the available live transcription languages" : "Canlı yazıya dönüştürme için kullanılabilecek diller yüklenirken sorun çıktı",
    "Failed to enable live transcription" : "Canlı yazıya dönüştürme açılamadı",
    "Failed to enable live translations" : "Canlı çeviriler açılamadı",
    "Failed to disable live translations" : "Canlı çeviriler kapatılamadı",
    "Recording consent is required" : "Kayıt alma rızası isteniyor",
    "This conversation is read-only" : "Bu görüşme salt okunur",
    "Conversation not found or not joined" : "Görüşme bulunamadı ya da görüşmeye katılınmamış",
    "Lobby is still active and you're not a moderator" : "Giriş hala kullanılıyor ve siz bir sorumlu değilsiniz",
    "Connection failed" : "Bağlantı kurulamadı",
    "Reload" : "Yeniden yükle",
    "{nickName} raised their hand." : "{nickName} elini kaldırdı.",
    "A participant raised their hand." : "Bir katılımcı elini kaldırdı.",
    "Collapse stripe" : "Şeridi daralt",
    "Expand stripe" : "Şeridi genişlet",
    "Previous page of videos" : "Önceki görüntü sayfası",
    "Next page of videos" : "Sonraki görüntü sayfası",
    "Connecting …" : "Bağlantı kuruluyor …",
    "Calling …" : "Aranıyor…",
    "Waiting for {user} to join the call" : "{user} kullanıcısının çağrıya katılması bekleniyor",
    "Waiting for others to join the call …" : "Diğerlerinin çağrıya katılması bekleniyor …",
    "You can invite others in the participant tab of the sidebar" : "Diğer kişileri kenar çubuğundaki katılımcı sekmesinden davet edebilirsiniz",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Diğer kişileri kenar çubuğundaki katılımcı sekmesinden ya da bu bağlantıyı paylaşarak davet edebilirsiniz!",
    "Share this link to invite others!" : "Diğer kişileri davet etmek için bu bağlantıyı paylaşın!",
    "Copy link" : "Bağlantıyı kopyala",
    "You are not allowed to enable audio" : "Sesi açma izniniz yok",
    "No audio. Click to select device" : "Ses yok. Aygıtı seçmek için tıklayın",
    "Mute audio" : "Sesi kıs",
    "Mute audio (M)" : "Sesi kıs (M)",
    "Unmute audio" : "Sesi aç",
    "Unmute audio (M)" : "Sesi aç (M)",
    "None" : "Yok",
    "Select a microphone" : "Bir mikrofon seçin",
    "Select a speaker" : "Bir hoparlör seçin",
    "Microphone settings" : "Mikrofon ayarları",
    "Check devices" : "Aygıtları denetle",
    "Access to camera was denied" : "Kameraya erişim reddedildi",
    "Error while accessing camera: It is likely in use by another program" : "Kameraya erişilirken sorun çıktı: Başka bir uygulama tarafından kullanılıyor olabilir",
    "Error while accessing camera" : "Kameraya erişilirken sorun çıktı",
    "You have been muted by a moderator" : "Sesiniz sorumlu tarafından kısıldı",
    "Hide presenter video" : "Sunucunun görüntüsünü gizle",
    "You are not allowed to enable video" : "Görüntüyü açma izniniz yok",
    "No video. Click to select device" : "Görüntü yok. Aygıtı seçmek için tıklayın",
    "Disable video" : "Görüntüyü kapat",
    "Disable video (V)" : "Görüntüyü kapat (V)",
    "Enable video" : "Görüntü kullanılsın",
    "Enable video (V)" : "Görüntüyü aç (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Görüntüyü aç. Görüntü ilk kez açılırken bağlantınız bir an kesilecek",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Görüntüyü aç (V) - Görüntü ilk kez açıldığında bağlantınız kısa süreli olarak kesilecek",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Görüntüyü aç. Görüntü ilk kez açılırken bağlantınız bir an kesilecek",
    "Select a video device" : "Bir görüntü aygıtı seçin",
    "Show presenter" : "Sunucu görüntülensin",
    "You" : "Siz",
    "Mute" : "Sesi kıs",
    "Muted" : "Sesi kapalı",
    "Show screen" : "Ekranı görüntüle",
    "Stop following" : "Takibi bırak",
    "Connection could not be established …" : "Bağlantı kurulamadı…",
    "Connection was lost and could not be re-established …" : "Bağlantı kesildi ve yeniden kurulamadı…",
    "Connection could not be established. Trying again …" : "Bağlantı kurulamadı. Yeniden deneniyor…",
    "Connection lost. Trying to reconnect …" : "Bağlantı kesildi. Yeniden deneniyor…",
    "Connection problems …" : "Bağlantı sorunları…",
    "Collapse" : "Daralt",
    "Expand" : "Genişlet",
    "You need to be logged in to upload files" : "Dosya yükleyebilmek için oturum açmalısınız",
    "Drop your files to upload" : "Yüklenecek dosyaları sürükleyip bırakın",
    "Conversation messages" : "Görüşme iletileri",
    "Scroll to bottom" : "Aşağıya kaydır",
    "Post message" : "İleti gönder",
    "Federated conversation" : "Birleşik görüşme",
    "Public conversation" : "Herkese açık görüşme",
    "Favorite" : "Sık kullanılanlara ekle",
    "Banned users" : "Yasaklanmış kullanıcılar",
    "Manage the list of banned users in this conversation." : "Bu görüşmede yasaklanmış kullanıcıların listesini yönetir.",
    "Manage bans" : "Yasaklama yönetimi",
    "No banned users" : "Yasaklanmış bir kullanıcı yok",
    "Banned by:" : "Yasaklayan:",
    "Date:" : "Tarih:",
    "Note:" : "Not:",
    "Hide details" : "Ayrıntıları gizle",
    "Show details" : "Ayrıntıları görüntüle",
    "Unban" : "Yasaklamayı kaldır",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "{linkstart}Takvim ↗{linkend} içindeki başlık ve açıklamayı değiştirebilirsiniz.",
    "Error while updating conversation name" : "Görüşme adı güncellenirken sorun çıktı",
    "Error while updating conversation description" : "Görüşme açıklaması güncellenirken sorun çıktı",
    "Enter a name for this conversation" : "Bu görüşme için bir ad yazın",
    "Edit conversation name" : "Görüşme adını düzenle",
    "Edit conversation description" : "Görüşme açıklamasını düzenle",
    "Enter a description for this conversation" : "Bu görüşme için bir açıklama yazın",
    "Picture" : "Fotoğraf",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Bu görüşmede şu botlar kullanılabilir. Bu sunucuya daha fazla bot kurması için yöneticiniz ile görüşün.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Bu sunucuya herhangi bir bot kurulmamış. Bu sunucuya botları kurması için yöneticiniz ile görüşün.",
    "Disable" : "Kullanımdan kaldır",
    "Enable" : "Aç",
    "Breakout rooms" : "Çalışma odaları",
    "Manage breakout rooms" : "Çalışma odaları yönetimi",
    "Set up breakout rooms for this conversation" : "Bu görüşme için çalışma odalarını hazırla",
    "Please select a valid PNG or JPG file" : "Lütfen geçerli bir PNG ya da JPG dosyası seçin",
    "Choose your conversation picture" : "Görüşme görselinizi seçin",
    "Choose" : "Seçin",
    "Error setting conversation picture" : "Görüşme görseli ayarlanırken sorun çıktı",
    "Could not set the conversation picture: {error}" : "Görüşme görseli ayarlanamadı: {error}",
    "Error cropping conversation picture" : "Görüşme görseli kırpılırken sorun çıktı",
    "Error removing conversation picture" : "Görüşme görseli kaldırılırken sorun çıktı",
    "Set emoji as conversation picture" : "Emojiyi görüşme görseli olarak ayarla",
    "Set background color for conversation picture" : "Arka plan rengini görüşme görseli olarak ayarla",
    "Upload conversation picture" : "Görüşme görseli yükle",
    "Choose conversation picture from files" : "Görüşme görselini dosyalardan seçin",
    "Remove conversation picture" : "Görüşme görselini kaldır",
    "The file must be a PNG or JPG" : "Dosya PNG ya da JPG biçiminde olmalıdır",
    "Set picture" : "Görseli ayarla",
    "Default permissions modified for {conversationName}" : "{conversationName} için varsayılan izinler değiştirildi",
    "Could not modify default permissions for {conversationName}" : "{conversationName} için varsayılan izinler değiştirilemedi",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Bu görüşmedeki katılımcıların varsayılan izinlerini düzenleyin. Sorumlular bu ayarlardan etkilenmez.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Bu bölümdeki izinler her değiştirildiğinde, daha önce katılımcılara tek tek atanmış özel izinler kaybolur.",
    "All permissions" : "Tüm izinler",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Katılımcıların bir çağrı başlatma, bir çağrıya katılma, ses, görüntü ve ekran paylaşımını açma izinleri vardır.",
    "Restricted" : "Kısıtlanmış",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Katılımcılar yalnızca çağrılara katılabilir, ancak bir sorumlu izinlerini el ile verene kadar ses, görüntü veya ekran paylaşımını açamaz.",
    "Advanced permissions" : "Gelişmiş izinler",
    "Edit permissions" : "İzinleri düzenle",
    "Conversation settings" : "Görüşme ayarları",
    "Basic Info" : "Temel bilgiler",
    "Personal" : "Kişisel",
    "Moderation" : "Yönetim",
    "Setup overview" : "Kurulum özeti",
    "Live transcription" : "Canlı yazıya dönüştürme",
    "Enable live transcription" : "Canlı yazıya dönüştürmeyi aç",
    "Breakout Rooms" : "Çalışma odaları",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Botlar",
    "Danger zone" : "Tehlikeli bölge",
    "Archive conversation" : "Görüşmeyi arşivle",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Arşivlenmiş görüşmeler varsayılan olarak görüşme listesinde gizlenir. Ancak, görüşme adını aradığınızda veya arşivlenmiş görüşmeler listesine eriştiğinizde görüntülenirler.",
    "Do you really want to leave \"{displayName}\"?" : "\"{displayName}\" görüşmesinden ayrılmak istediğinize emin misiniz?",
    "You can archive this conversation instead." : "Bunun yerine bu görüşmeyi arşivleyebilirsiniz.",
    "Leave conversation" : "Görüşmeden ayrıl",
    "You need to promote a new moderator before you can leave the conversation" : "Görüşmeden ayrılmadan önce başka bir kullanıcıyı sorumluluğa yükseltmelisiniz",
    "Delete conversation" : "Görüşmeyi sil",
    "Do you really want to delete \"{displayName}\"?" : "\"{displayName}\" ögesini silmek istediğinize emin misiniz?",
    "Error while deleting conversation" : "Görüşme silinirken sorun çıktı",
    "Delete all chat messages" : "Tüm sohbet iletilerini sil",
    "Do you really want to delete all messages in \"{displayName}\"?" : "\"{displayName}\" içindeki tüm iletileri silmek istediğinize emin misiniz?",
    "Error while clearing chat history" : "Sohbet geçmişi silinirken sorun çıktı",
    "Be careful, these actions cannot be undone." : "Dikkatli olun, bu işlemler geri alınamaz.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Bir görüşmeden ayrıldıktan sonra, kapalı bir sohbete yeniden katılmak için davet edilmek gerekir. Açık bir sohbete herhangi bir zamanda yeniden katılabilirsiniz.",
    "Permanently delete this conversation." : "Bu görüşmeyi kalıcı olarak sil.",
    "Delete chat messages" : "Sohbet iletilerini sil",
    "Permanently delete all the messages in this conversation." : "Bu görüşmedeki tüm iletileri sil.",
    "_%n hour_::_%n hours_" : ["%n saat","%n saat"],
    "_%n day_::_%n days_" : ["%n gün","%n gün"],
    "_%n week_::_%n weeks_" : ["%n hafta","%n hafta"],
    "Custom expiration time" : "Özel geçerlilik süresi",
    "Message expiration disabled" : "İleti geçerlilik süresi kapalı",
    "Message expiration set: {duration}" : "Ayarlanmış ileti geçerlilik süresi: {duration}",
    "Error when trying to set message expiration" : "İleti geçerlilik süresi ayarlanırken sorun çıktı",
    "Message expiration" : "Süreli ileti",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Sohbet iletileri süresi belirli bir süre sonra dolacak şekilde ayarlanabilir. Not: Süresi dolan iletlerdeki dosyalar sahibi için silinmez, ancak artık görüşmede paylaşılmaz.",
    "Set message expiration" : "İletinin geçerlilik süresini ayarlayın",
    "Current message expiration" : "Geçerli iletinin geçerlilik süresi",
    "Password copied to clipboard" : "Parola panoya kopyalandı",
    "Password could not be copied" : "Parola panoya kopyalanamadı",
    "Guest access" : "Konuk erişimi",
    "Breakout rooms are not allowed in public conversations." : "Herkese açık görüşmelerde çalışma odaları kullanılamaz",
    "Allow guests to join this conversation via link" : "Konuklar bu görüşmeye bağlantı ile katılabilsin",
    "Password protection" : "Parola koruması",
    "This conversation is password-protected. Guests need password to join" : "Bu görüşme parola ile korunmuş. Konukların katılabilmesi için parolayı bilmeleri gerekir",
    "Password protection is needed for public conversations" : "Herkese açık görüşmeler için parola ile korunması gereklidir",
    "Set a password" : "Bir parola ayarlayın",
    "Change password" : "Parolayı değiştir",
    "Enter new password" : "Yeni parolayı yazın",
    "Save password" : "Parolayı kaydet",
    "Copy password" : "Parolayı kopyala",
    "Guests are allowed to join this conversation via link" : "Konuklar bu görüşmeye bağlantı ile katılabilir",
    "Guests are not allowed to join this conversation" : "Konuklar bu görüşmeye katılamaz",
    "Resend invitations" : "Davetleri yeniden gönder",
    "This conversation is open to both registered users and users created with the Guests app" : "Bu görüşmeye katılım, hem hesabı olan kullanıcılara hem de Konuklar uygulaması ile oluşturulan kullanıcılara açık",
    "This conversation is open to registered users" : "Bu görüşmeye katılım, hesabı olan kullanıcılara açık",
    "This conversation is limited to the current participants" : "Bu görüşmeye katılım, geçerli katılımcılar ile sınırlı",
    "You opened the conversation to both registered users and users created with the Guests app" : "Görüşmeye katılımı, hem hesabı olan kullanıcılara ve hem de Konuklar uygulaması ile oluşturulan kullanıcılara açtınız",
    "Error occurred when opening or limiting the conversation" : "Görüşme açılır ya da kısıtlanırken sorun çıktı",
    "Open conversation to registered users, showing it in search results" : "Görüşme hesabı olan kullanıcılara açılarak arama sonuçlarında görüntülensin",
    "Also open to users created with the Guests app" : "Konuklar uygulaması ile oluşturulmuş kullanıcılara da açık",
    "Open conversation" : "Açık görüşme",
    "Set language spoken in calls" : "Çağrılarda konuşulan dili ayarlayın",
    "Languages could not be loaded" : "Diller yüklenemedi",
    "Loading languages …" : "Diller yükleniyor…",
    "Invalid language" : "Dil geçersiz",
    "Default language (English)" : "Varsayılan dil (İngilizce)",
    "Default live transcription language set" : "Varsayılan canlı yazıya dönüştürme dili ayarlandı",
    "Live transcription language set: {languageName}" : "Ayarlanmış canlı yazıya dönüştürme dili: {languageName}",
    "Error when trying to set live transcription language" : "Canlı yazıya dönüştürme dili ayarlanırken sorun çıktı",
    "Start time: {date}" : "Başlangıç zamanı: {date}",
    "Start time has been updated" : "Başlangıç saati güncellendi",
    "Error occurred while updating start time" : "Başlangıç saati güncellenirken sorun çıktı",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Giriş kullanıma alındığında, sorumlu olmayanlar sürmekte olan çağrıdan çıkarılır.",
    "Enable lobby, restricting the conversation to moderators" : "Girişi kullanıma al, görüşmeyi sorumlular ile kısıtla",
    "Meeting start time" : "Toplantının başlangıç saati",
    "Start time (optional)" : "Başlangıç zamanı (isteğe bağlı)",
    "Import email participants" : "E-posta katılımcılarını içe aktar",
    "You can import a list of email participants from a CSV file." : "E-posta katılımcılarını bir CSV dosyası ile içe aktarabilirsiniz.",
    "Poll drafts" : "Anket taslakları",
    "Browse poll drafts" : "Anket taslaklarına göz at",
    "Error occurred when locking the conversation" : "Görüşme kilitlenirken sorun çıktı",
    "Error occurred when unlocking the conversation" : "Görüşmenin kilidi açılırken sorun çıktı",
    "Lock conversation" : "Görüşmeyi kilitle",
    "This will also terminate the ongoing call." : "Bu işlem ayrıca sürmekte olan çağrıyı sonlandırır.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Görüşmeyi kilitleyerek, ileti gönderilmesini ya da çağrı başlatılmasını engelle",
    "Edit" : "Düzenle",
    "More information" : "Diğer bilgiler",
    "Delete" : "Sil",
    "Add new bridged channel to current conversation" : "Geçerli görüşmeye yeni bir köprülenmiş kanal ekle",
    "unknown state" : "durum bilinmiyor",
    "running" : "çalışıyor",
    "not running, check Matterbridge log" : "çalışmıyor. Matterbridge günlüğünü denetleyin",
    "not running" : "çalışmıyor",
    "Bridge saved" : "Köprü kaydedildi",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Matterbridge kullanarak çeşitli anlık ileti sistemlerindeki kanallar ile köprü kurabilirsiniz.",
    "More info on Matterbridge" : "Matterbridge hakkında ayrıntılı bilgiler",
    "Messaging systems" : "İleti sistemleri",
    "Enable bridge" : "Köprü kullanılsın",
    "Show Matterbridge log" : "Matterbridge günlüğünü görüntüle",
    "Log content" : "Günlük içeriği",
    "Only moderators are allowed to mention @all" : "Yalnızca sorumlular @all anmasını kullanabilir",
    "All participants are allowed to mention @all" : "Tüm katılımcılar @all anmasını kullanabilir",
    "Participants are now allowed to mention @all." : "Katılımcılar artık @all anmasını kullanabilir.",
    "Mentioning @all has been limited to moderators." : "@all anmasını artık yalnızca sorumlular kullanabilir.",
    "Allow participants to mention @all" : "Katılımcılar @all anmasını kullanabilsin",
    "Mention permissions" : "Anma izinleri",
    "Notifications" : "Bildirimler",
    "Notify about calls in this conversation" : "Bu görüşmedeki çağrılar bildirilsin",
    "Important conversation" : "Önemli görüşme",
    "\"Do not disturb\" user status is ignored for important conversations" : "Önemli görüşmeler için \"Rahatsız etmeyin\" kullanıcı durumu yok sayılır",
    "Sensitive conversation" : "Ciddi görüşme",
    "Message preview will be disabled in conversation list and notifications" : "Görüşme listesi ve bildirimlerde ileti ön izlemesi kapatılacak",
    "Recording consent is required for calls in this conversation" : "Bu görüşmedeki çağrılar için kayıt alma rızası istenir",
    "Recording consent is not required for calls in this conversation" : "Bu görüşmedeki çağrılar için kayıt alma rızası istenmez",
    "Recording consent requirement was updated" : "Kayıt alma rızası güncellendi",
    "Error occurred while updating recording consent" : "Kayıt alma rızası güncellenirken sorun çıktı",
    "Recording Consent" : "Kayıt alma rızası",
    "Recording consent cannot be changed once a call or breakout session has started." : "Bir çağrı ya da çalışma odası oturumu başladıktan sonra kayıt alma rızası değiştirilemez.",
    "Require recording consent before joining call in this conversation" : "Bu görüşmedeki çağrılara katılmadan önce kayıt alma rızası istensin",
    "Recording consent is required for all calls" : "Tüm çağrılar için kayıt alma rızası istensin",
    "SIP dial-in is now possible without PIN requirement" : "Artık PIN kodu gerekmeden SIP araması yapılabilir",
    "SIP dial-in is now enabled" : "SIP çevirmeli arama kullanıma alındı",
    "SIP dial-in is now disabled" : "SIP çevirmeli arama kullanımdan kaldırıldı",
    "Error occurred when enabling SIP dial-in" : "SIP çevirmeli arama kullanıma alınırken sorun çıktı",
    "Error occurred when disabling SIP dial-in" : "SIP çevirmeli arama kullanımdan kaldırılırken sorun çıktı",
    "Phone and SIP dial-in" : "Telefon ve SIP çevirme",
    "Enable phone and SIP dial-in" : "Telefon ve SIP çevirme özelliğini kullanıma al",
    "Allow to dial-in without a PIN" : "Pin kodu olmadan numara aranabilsin",
    "Ongoing" : "Sürüyor",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n kişi kabul etti","%n kişi kabul etti"],
    "_%n person declined_::_%n people declined_" : ["%n kişi reddetti","%n kişi reddetti"],
    "_and %n other attachment_::_and %n other attachments_" : ["ve %n diğer ek dosya","ve %n diğer ek dosya"],
    "With {displayName}" : "{displayName} ile",
    "In {conversation}" : "{conversation} içinde",
    "View attachment" : "Ek dosyayı görüntüle",
    "Join" : "Katıl",
    "View conversation" : "Görüşmeyi görüntüle",
    "View event on Calendar" : "Etkinliği takvimde görüntüle",
    "Error while creating the conversation" : "Görüşme oluşturulurken sorun çıktı",
    "Hello, {displayName}" : "Merhaba, {displayName}",
    "Start meeting now" : "Toplantıyı başlat",
    "Give your meeting a title" : "Toplantınıza bir ad verin",
    "Create and copy link" : "Bağlantıyı oluşturup kopyalayın",
    "Create a new conversation" : "Yeni bir görüşme oluştur",
    "Join open conversations" : "Açık görüşmelere katıl",
    "Call a phone number" : "Bir telefon numarasını ara",
    "Scroll backward" : "Geriye kaydır",
    "Scroll forward" : "İleriye kaydır",
    "Schedule meetings" : "Toplantı zamanla",
    "You don't have any upcoming meetings" : "Yaklaşan bir toplantınız yok",
    "Open calendar" : "Takvimi aç",
    "Unread mentions" : "Okunmamış anmalar",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Anıldığınız iletiler burada görüntülenir. @ ve ardından adlarını yazarak insanları anabilirsiniz",
    "Upcoming reminders" : "Yaklaşan anımsatıcılar",
    "Message reminders" : "İleti anımsatıcıları",
    "Set a reminder on a message to be notified" : "Daha sonra yeniden bilgilendirilmek için bir iletiye bir anımsatıcı ayarlayın",
    "Start a group conversation" : "Bir grup görüşmesi başlat",
    "Create conversation" : "Görüşme oluştur",
    "Enter your name" : "Adınızı yazın",
    "Submit name and join" : "Adı gönder ve katıl",
    "Do you already have an account?" : "Zaten bir hesabınız var mı?",
    "Log in" : "Oturum aç",
    "Error while verifying uploaded file" : "Yüklenmiş dosya doğrulanırken sorun çıktı",
    "Uploaded file is verified" : "Yüklenmiş dosya doğrulandı",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "İçerik biçimi virgül ile ayrılmış değerlerdir (CSV):<br/>- Başlık satırı zorunlludur ve <samp>\"name\",\"email\"</samp> veya yalnızca <samp>\"email\"</samp> ile eşleşmelidir<br/>- Her satıra yalnızca bir kayıt yazılmalıdır (örneğin <samp>\"Ali Kaya\",\"alikaya@ornek.tld\"</samp>)",
    "Participants added successfully" : "Katılımcılar eklendi",
    "Error while adding participants" : "Katılımcılar eklenirken sorun çıktı",
    "Import a file" : "Dosyadan içe aktar",
    "Browse" : "Göz at",
    "Verifying uploaded file …" : "Yüklenen dosya doğrulanıyor…",
    "This might take a moment" : "Bu işlemin tamamlanması biraz zaman alabilir",
    "Send invitations" : "Davetleri gönder",
    "_%n invalid email_::_%n invalid emails_" : ["%n e-posta adresi geçersiz","%n e-posta adresi geçersiz"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n e-posta adresi zaten içe aktarılmış ya da çift","%n e-posta adresi zaten içe aktarılmış ya da çift"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n davet gönderilemedi","%n davet gönderilemedi"],
    "An error occurred while calling a phone number" : "Bir telefon numarası aranırken bir sorun çıktı",
    "Phone number could not be called: {error}" : "Telefon numarası aranamadı: {error}",
    "Phone number could not be called" : "Telefon numarası aranamadı",
    "Search participants or phone numbers" : "Katılımcı ya da telefon numarası ara",
    "Creating the conversation …" : "Görüşme oluşturuluyor…",
    "Mark as read" : "Okunmuş olarak işaretle",
    "Mark as unread" : "Okunmamış olarak işaretle",
    "Remove from favorites" : "Sık kullanılanlardan kaldır",
    "Add to favorites" : "Sık kullanılanlara ekle",
    "Unarchive conversation" : "Görüşmeyi arşivden çıkar",
    "Ignore \"Do not disturb\"" : "\"Rahatsız etmeyin\" yok sayılsın",
    "You need to promote a new moderator before you can leave the conversation." : "Görüşmeden ayrılmadan önce başka bir kullanıcıyı sorumluluğa yükseltmelisiniz.",
    "Conversation actions" : "Görüşme işlemleri",
    "Notify about calls" : "Çağrılar bildirilsin",
    "Hide message text" : "İleti yazısı gizlensin",
    "Pending invitations" : "Bekleyen davetler",
    "Join conversations from other servers" : "Başka sunuculardaki görüşmelere katıl",
    "From {user} at {remoteServer}" : "{remoteServer} sunucusundaki {user} kullanıcısından",
    "Decline invitation" : "Daveti reddet",
    "Accept invitation" : "Daveti kabul et",
    "No pending invitations" : "Bekleyen bir davet yok",
    "Home" : "Giriş",
    "Unread" : "Okunmamış",
    "Mentions" : "Anmalar",
    "Meetings" : "Toplantılar",
    "Alphabetically" : "Alfabetik",
    "No followed threads" : "Takip edilen bir yazışma yok",
    "No matches found" : "Eşleşen bir sonuç bulunamadı",
    "No conversations found" : "Herhangi bir görüşme bulunamadı",
    "You have no archived conversations." : "Arşivlenmiş bir görüşmeniz yok.",
    "Subscribe to an existing thread or start your own." : "Var olan bir yazışmaya abone olun ya da kendi yazışmanızı başlatın.",
    "You have no unread mentions." : "Okunmamış bir anmanız yok.",
    "You have no unread messages." : "Okunmamış bir iletiniz yok.",
    "An error occurred while performing the search" : "Arama sırasında bir sorun çıktı",
    "Conversation list" : "Görüşme listesi",
    "Filter conversations by" : "Görüşmeleri şuna göre süz",
    "Unread messages" : "Okunmamış iletiler",
    "Meeting conversations" : "Toplantı görüşmeleri",
    "Clear filters" : "Süzgeçleri temizle",
    "New personal note" : "Yeni kişisel not",
    "Back to conversations" : "Görüşmelere dön",
    "Archived conversations" : "Arşivlenmiş görüşmeler",
    "Threads" : "Yazışmalar",
    "Clear filter" : "Süzgeci temizle",
    "Show more threads" : "Diğer yazışmaları görüntüle",
    "App settings" : "Uygulama ayarları",
    "Users" : "Kullanıcılar",
    "Groups" : "Gruplar",
    "Teams" : "Takımlar",
    "Federated users" : "Birleşik kullanıcılar",
    "New private conversation" : "Yeni özel görüşme",
    "Other sources" : "Diğer kaynaklar",
    "Open conversations" : "Açık görüşmeler",
    "No search results" : "Aramadan bir sonuç alınamadı",
    "Users, groups and teams" : "Kullanıcılar, gruplar ve takımlar",
    "Users and groups" : "Kullanıcılar ve gruplar",
    "Users and teams" : "Kullanıcılar ve takımlar",
    "Groups and teams" : "Gruplar ve takımlar",
    "New group conversation" : "Yeni grup görüşmesi",
    "The meeting will start soon" : "Toplantı yakında başlayacak",
    "This meeting is scheduled for {startTime}" : "Bu toplantının başlangıcı {startTime} olarak ayarlanmış",
    "You are currently waiting in the lobby" : "Şu anda girişte bekliyorsunuz",
    "Enable noise suppression" : "Gürültü engellemeyi aç",
    "Reduce background noises for better voice quality" : "Daha iyi ses kalitesi için arka plan gürültüsünü azaltır",
    "Enable echo cancellation" : "Yansıma engellemeyi aç",
    "Minimize echo effect from own surrounding" : "Çevrenizden kaynaklanan yankı etkisini en aza indirir",
    "Enable auto gain control" : "Otomatik güçlendirmeyi aç",
    "Dynamically adjust microphone volume for consistent level" : "Tutarlı bir ses düzeyi için mikrofon güçlendirmesini dinamik olarak ayarlar",
    "Select microphone" : "Mikrofonu seçin",
    "No microphone available" : "Kullanılabilecek bir mikrofon yok",
    "Select speaker" : "Konuşmacıyı seçin",
    "No speaker available" : "Herhangi bir konuşmacı yok",
    "Select camera" : "Kamerayı seçin",
    "No camera available" : "Kullanılabilecek bir kamera bulunamadı",
    "Select a device" : "Bir aygıt seçin",
    "Playing …" : "Çalınıyor…",
    "Test speakers" : "Hoparlörleri sına",
    "Test" : "Sına",
    "Devices" : "Aygıtlar",
    "Backgrounds" : "Arka planlar",
    "No audio" : "Ses yok",
    "No camera" : "Kamera yok",
    "Display video as you will see it (mirrored)" : "Görüntü sizin göreceğiniz gibi görüntülensin (ayna yansıması)",
    "Display video as others will see it" : "Görüntü diğerlerinin göreceği gibi görüntülensin",
    "Calls are not supported in your browser" : "Tarayıcınız çağrıları desteklemiyor",
    "Access to microphone is only possible with HTTPS" : "Mikrofona yalnızca HTTPS üzerinden erişilebilir",
    "Access to microphone was denied" : "Mikrofona erişim reddedildi",
    "Error while accessing microphone" : "Mikrofon erişilirken sorun çıktı",
    "Access to camera is only possible with HTTPS" : "Kameraya yalnızca HTTPS üzerinden erişilebilir",
    "The call is being recorded." : "Çağrı kaydediliyor.",
    "The call might be recorded." : "Çağrının kaydı alınabilir.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Kayıtta sesiniz, kamera görüntünüz ve ekran paylaşımlarınız bulunabilir. Çağrıya katılmadan önce kayıt alma rızası vermeniz gerekir.",
    "Give consent to the recording of this call" : "Bu çağrı için kayıt alma rızası verin",
    "Show more info" : "Diğer bilgileri görüntüle",
    "Audio is not available" : "Ses kullanılamıyor",
    "Video is not available" : "Görüntü kullanılamıyor",
    "Start recording immediately with the call" : "Kayıt çağrı başlangıcında başlatılsın",
    "Notify all participants about this call" : "Bu çağrı tüm katılımcılara bildirilsin",
    "Apply settings" : "Ayarları uygula",
    "Select virtual office background" : "Sanal ofis arka planını seçin",
    "Select virtual home background" : "Sanal ev arka planını seçin",
    "Select virtual abstract background" : "Sanal soyut arka planını seçin",
    "Select virtual beach background" : "Sanal kumsal arka planını seçin",
    "Select virtual park background" : "Sanal park arka planını seçin",
    "Select virtual theater background" : "Sanal sahne arka planını seçin",
    "Select virtual library background" : "Sanal kütüphane arka planını seçin",
    "Select virtual space station background" : "Sanal uzay istasyonu arka planını seçin",
    "Error while uploading the file" : "Dosya yüklenirken sorun çıktı",
    "Select a file" : "Bir dosya seçin",
    "Invalid path selected" : "Seçilen yol geçersiz",
    "Select virtual background from file {fileName}" : "{fileName} sanal arka planını seçin",
    "Blur" : "Bulanıklaştır",
    "Upload" : "Yükle",
    "Files" : "Dosyalar",
    "(editing)" : "(düzenleniyor)",
    "(edited)" : "(düzenlendi)",
    "The message has expired or has been deleted" : "İletinin süresi geçmiş ya da silinmiş.",
    "Cancel quote" : "Alıntıyı iptal et",
    "24 hours" : "24 saat",
    "7 days" : "7 gün",
    "30 days" : "30 gün",
    "Until unpin" : "Sabitleme kaldırılana kadar",
    "Clear reminder – {timeLocale}" : "Anımsatıcıyı temizle – {timeLocale}",
    "Edited by {actor}" : "{actor} tarafından düzenlendi",
    "Pinned by you" : "Sabitledikleriniz",
    "Pinned by {actor}" : "{actor} tarafından sabitlenmişler",
    "Until {absoluteDate}" : "{absoluteDate} tarihine kadar",
    "Message text copied to clipboard" : "İleti yazısı panoya kopyalandı",
    "Message text could not be copied" : "İleti yazısı kopyalanamadı",
    "Message forwarded to \"Note to self\"" : "İleti \"Kendime not\" olarak iletildi",
    "Error while forwarding message to \"Note to self\"" : "İleti \"Kendime not\" olarak iletilirken sorun çıktı",
    "A reminder was successfully removed" : "Bir anımsatıcı silindi",
    "Error occurred when removing a reminder" : "Bir anımsatıcı silinirken sorun çıktı",
    "A reminder was successfully set at {datetime}" : "{datetime} için bir anımsatıcı ayarlandı",
    "Error occurred when creating a reminder" : "Anımsatıcı oluşturulurken sorun çıktı",
    "Add a reaction to this message" : "Bu iletiye bir tepki ekle",
    "Reply" : "Yanıtla",
    "More actions" : "Diğer işlemler",
    "Set reminder" : "Anımsatıcı ayarla",
    "Pin message" : "İletiyi sabitle",
    "Unpin message" : "İletinin sabitlemesini kaldır",
    "Reply privately" : "Kişisel yanıt gönder",
    "Edit message" : "İletiyi düzenle",
    "Copy message" : "İletiyi kopyala",
    "Copy message link" : "İleti bağlantısını kopyala",
    "Go to file" : "Dosyaya git",
    "Download file" : "Dosyayı indir",
    "Go to thread" : "Yazışmaya git",
    "Edit thread details" : "Yazışma ayrıntılarını düzenle",
    "Forward message" : "İletiyi ilet",
    "Translate" : "Çevir",
    "Set custom reminder" : "Özel anımsatıcı ayarla",
    "Keep pinned for" : "Şu kadar sabitlensin",
    "Set custom period" : "Özel aralık ayarla",
    "Close reactions menu" : "Tepkiler menüsünü kapat",
    "React with {emoji}" : "{emoji} ile tepki ver",
    "React with another emoji" : "Başka bir emoji ile tepki ver",
    "Choose a conversation to forward the selected message." : "Seçilmiş iletinin iletileceği bir görüşme seçin.",
    "Error while forwarding message" : "İleti iletilirken bir sorun çıktı",
    "The message has been forwarded to {selectedConversationName}" : "İleti {selectedConversationName} üzerine iletildi",
    "Dismiss" : "Yok say",
    "Go to conversation" : "Görüşmeye git",
    "Detect language" : "Dili algıla",
    "The message could not be translated" : "İleti çevrilemedi",
    "Translation copied to clipboard" : "Çeviri panoya kopyalandı",
    "Translation could not be copied" : "Çeviri kopyalanamadı",
    "Translate message" : "İletiyi çevir",
    "Source language to translate from" : "Çevirinin yapılacağı kaynak dil",
    "Translate from" : "Kaynak dil",
    "Target language to translate into" : "Çevirinin yapılacağı hedef dil",
    "Translate to" : "Hedef dil",
    "Translating" : "Çevriliyor",
    "Copy translated text" : "Çevrilmiş yazıyı kopyala",
    "Error when scheduling the message" : "İleti zamanlanırken sorun çıktı",
    "Reschedule" : "Yeniden zamanla",
    "Send now" : "Şimdi gönder",
    "Choose a time" : "Bir zaman seçin",
    "Send at custom time" : "Özel bir zamanda gönderilsin",
    "Will be sent without notification" : "Bildirim olmadan gönderilecek",
    "Message read by everyone who shares their reading status" : "İleti okundu durumunu paylaşan herkes tarafından okundu",
    "Message sent" : "İleti gönderildi",
    "Sent without notification" : "Bildirim olmadan gönderildi",
    "Deleting message" : "İleti siliniyor",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "İleti silindi ancak bir bot ya da Matterbridge yapılandırılmış ve ileti başka hizmetlere aktarılmış olabilir",
    "Message deleted successfully" : "İleti silindi",
    "Message could not be deleted because it is too old" : "İleti çok eski olduğundan silinemedi",
    "Only normal chat messages can be deleted" : "Yalnızca normal sohbet iletileri silinebilir",
    "An error occurred while deleting the message" : "İleti silinirken bir sorun çıktı",
    "Pinned" : "Sabitlenmiş",
    "Your browser does not support playing audio files" : "Tarayıcınız ses dosyalarının oynatılmasını desteklemiyor",
    "Contact" : "Kişi",
    "{stack} in {board}" : "{stack} {board} panosunda",
    "Deck Card" : "Tahta kartı",
    "Remove {fileName}" : "{fileName} dosyasını sil",
    "Open this location in OpenStreetMap" : "Bu konumu OpenStreetMap üzerinde aç",
    "_%n reply_::_%n replies_" : ["%n yanıt","%n yanıt"],
    "Sending message" : "İleti gönderiliyor",
    "Failed to send the message. Click to try again" : "İleti gönderilemedi. Yeniden denemek için tıklayın",
    "Not enough free space to upload file" : "Dosyayı yüklemek için yeterli boş alan yok",
    "You cannot send messages to this conversation at the moment" : "Şu anda bu görüşmeye ileti gönderemezsiniz",
    "Could not update the message" : "İleti güncellenemedi",
    "Reply to thread \"{threadTitle}\"" : "\"{threadTitle}\" konusunu yanıtla",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Oy verdiniz • %n oy","Oy verdiniz • %n oy"],
    "You voted" : "Oy verdiniz",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Oy vermek için tıklayın • %n oy","Oy vermek için tıklayın • %n oy"],
    "Click to vote" : "Oy vermek için tıklayın",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Anket taslağı • %n seçenek","Anket taslağı • %n seçenek"],
    "_%n vote_::_%n votes_" : ["%n oy","%n oy"],
    "Edit poll draft" : "Anket taslağını düzenle",
    "Delete poll draft" : "Anket taslağını sil",
    "Open poll" : "Açık anket",
    "Closed poll" : "Bitirilmiş anket",
    "See results" : "Sonuçları görüntüle",
    "Reactions" : "Tepkiler",
    "No permission to post reactions in this conversation" : "Bu görüşmeye tepki gönderme izniniz yok",
    "and {participant}" : "ve {participant}",
    "_and %n other participant_::_and %n other participants_" : ["ve %n diğer katılımcı","ve %n diğer katılımcı"],
    "Show all reactions" : "Tüm tepkileri görüntüle",
    "Add more reactions" : "Başka tepkiler ekle",
    "Show or collapse system messages" : "Sistem iletilerini görüntüle ya da gizle",
    "No messages" : "Herhangi bir ileti yok",
    "All messages have expired or have been deleted." : "Tüm iletilerin süresi geçmiş ya da silinmiş.",
    "Generate summary with AI" : "Yapay zeka ile özet oluştur",
    "{author} (pinned by you)" : "{author} (siz sabitlemişsiniz)",
    "{author} (pinned by {actor})" : "{author} ({actor} sabitlemiş)",
    "Unpin" : "Sabitlemeyi kaldır",
    "Cancel search" : "Aramayı iptal et",
    "Add a phone number" : "Telefon numarası ekle",
    "Error: A password is required to create the conversation." : "Hata: Görüşmeyi oluşturmak için bir parola gereklidir.",
    "All set, the conversation \"{conversationName}\" was created." : "Her şey tamam \"{conversationName}\" görüşmesi oluşturuldu.",
    "Create a new group conversation" : "Yeni bir grup görüşmesi oluştur",
    "Add participants" : "Katılımcı ekle",
    "Maximum length exceeded ({maxlength} characters)" : "Olabilecek en fazla uzunluk aşıldı ({maxlength} karakter)",
    "Conversation visibility" : "Görüşme görünürlüğü",
    "Allow guests to join via link" : "Konuklar bağlantı ile katılabilsin",
    "Enter password" : "Parolayı yazın",
    "This conversation has been locked" : "Bu görüşme kilitlenmiş",
    "No permission to post messages in this conversation" : "Bu görüşmeye ileti gönderme izniniz yok",
    "Joining conversation …" : "Görüşmeye giriliyor…",
    "Write a message without notification" : "Bildirim olmadan bir ileti yazın",
    "Create a thread silently" : "Sessizce bir yazışma oluştur",
    "Create a thread" : "Bir yazışma oluştur",
    "Send message silently" : "Sessizce ileti gönder",
    "Send message" : "İleti gönder",
    "Send without notification" : "Bildirim olmadan gönder",
    "The participant will not be notified about new messages" : "Yeni iletler katılımcıya bildirilmeyecek",
    "Participants will not be notified about new messages" : "Yeni iletler katılımcılara bildirilmeyecek",
    "Message will be sent {datetimeString}" : "İleti {datetimeString} zamanında gönderilecek",
    "Thread title is required" : "Yazışma başlığı yazılmalıdır",
    "Message text is required" : "İleti içeriği yazılmalıdır",
    "The message could not be edited" : "İleti düzenlenemedi",
    "File to share" : "Paylaşılacak dosya",
    "File upload is not available in this conversation" : "Bu görüşmeye dosya yüklenemez",
    "Message was successfully scheduled" : "İleti zamanlandı",
    "Add emoji" : "Emoji ekle",
    "Adding a mention will only notify users who did not read the message." : "Anma eklendiğinde yalnızca iletiyi henüz okumamış olan kullanıcılar bilgilendirilir",
    "Thread title" : "Yazışma başlığı",
    "Send later" : "Daha sonra gönder",
    "Show scheduled messages" : "Zamanlanmış iletileri görüntüle",
    "Cancel editing" : "Düzenlemeyi iptal et",
    "Schedule message" : "İletiyi zamanla",
    "{user} is out of office and might not respond." : "{user} iş yeri dışında ve yanıt veremeyebilir.",
    "Absence period: {startDate} - {endDate}" : "Bulunmama aralığı: {startDate} - {endDate}",
    "Replacement:" : "Yedek:",
    "Share from {nextcloud}" : "{nextcloud} üzerinden paylaş",
    "Share from Files" : "Dosyalar uygulamasından paylaş",
    "Share files to the conversation" : "Görüşmede dosya paylaş",
    "Upload from device" : "Aygıttan yükle",
    "Create new poll" : "Anket ekle",
    "Smart picker" : "Akıllı seçici",
    "Record voice message" : "Ses iletisi kaydet",
    "End recording and send" : "Kaydı bitirip gönder",
    "Dismiss recording" : "Kaydı sil",
    "Access to the microphone was denied" : "Mikrofona erişim reddedildi",
    "Microphone either not available or disabled in settings" : "Mikrofon kullanılamıyor ya da ayarlardan kapatılmış",
    "Error while recording audio" : "Ses kaydedilirken sorun çıktı",
    "Voice message {time} ({conversation})" : "Sesli ileti {time} ({conversation})",
    "Generating summary of unread messages …" : "Okunmamış iletilerin özeti oluşturuluyor…",
    "Summary is AI generated and might contain mistakes" : "Özet yapay zeka ile oluşturulmuştur ve hatalar olabilir",
    "Error occurred during a summary generation" : "Özet oluşturulurken bir sorun çıktı",
    "New file" : "Yeni dosya",
    "Blank" : "Boş",
    "Error while creating file" : "Dosya oluşturulurken sorun çıktı",
    "Create and share a new file" : "Yeni bir dosya oluşturup paylaş",
    "Name of the new file" : "Yeni dosyanın adı",
    "Create file" : "Dosya oluştur",
    "Someone is typing …" : "Biri yazıyor…",
    "{user1} is typing …" : "{user1} yazıyor…",
    "{user1} and {user2} are typing …" : "{user1} ve {user2} yazıyor…",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} ve {user3} yazıyor…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} ve %n diğer kişi yazıyor…","{user1}, {user2}, {user3} ve %n diğer kişi yazıyor…"],
    "Add more files" : "Başka dosya ekle",
    "Send" : "Gönder",
    "In this conversation <strong>{user}</strong> can:" : "Bu görüşmede <strong>{user}</strong> şunları yapabilir:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "<strong>{conversationName}</strong> içindeki katılımcıların varsayılan izinlerini düzenle",
    "Start a call" : "Bir çağrı başlat",
    "Skip the lobby" : "Girişi atla",
    "Can post messages" : "İleti gönderebilir",
    "Can post messages and reactions" : "İleti ve tepki gönderebilir",
    "Can add reactions" : "Tepki verebilir",
    "Enable the microphone" : "Mikrofonu aç",
    "Enable the camera" : "Kamerayı aç",
    "Share the screen" : "Ekranı paylaş",
    "Update permissions" : "İzinleri güncelle",
    "Updating permissions" : "İzinler güncelleniyor",
    "No poll drafts" : "Herhangi bir anket taslağı yok",
    "There is no poll drafts yet saved for this conversation" : "Bu görüşmede kaydedilmiş bir anket taslağı yok",
    "Create poll in {name}" : "{name} içinde anket oluştur",
    "Create poll" : "Anket ekle",
    "Error while importing poll" : "Anket içe aktarılırken sorun çıktı",
    "Question" : "Soru",
    "Ask a question" : "Bir soru sorun",
    "Import draft from file" : "Taslağı dosyadan içe aktar",
    "Answers" : "Yanıtlar",
    "Answer {option}" : "{option} yanıtı",
    "Delete poll option" : "Anket seçeneğini sil",
    "Add answer" : "Yanıt ekle",
    "Settings" : "Ayarlar",
    "Anonymous poll" : "Anonim anket",
    "Multiple answers" : "Birden çok yanıt",
    "Save as draft" : "Taslak olarak kaydet",
    "Export draft to file" : "Taslağı dosyaya dışa aktar",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Sonuçlar • %n oy","Sonuçlar • %n oy"],
    "Your vote is anonymous" : "Oyunuz anonim",
    "You voted for this option" : "Bu seçenek için oy verdiniz",
    "End poll" : "Anketi sonlandır",
    "Change your vote" : "Oyunuzu değiştirin",
    "Withdraw vote" : "Oyu geri çek",
    "Results" : "Sonuçlar",
    "Voted participants" : "Oy veren katılımcılar",
    "Send a message to \"{roomName}\"" : "\"{roomName}\" odasına bir ileti gönder",
    "Hide list of participants" : "Katılımcı listesini gizle",
    "Show list of participants" : "Katılımcı listesini görüntüle",
    "Assistance requested in {roomName}" : "{roomName} odasından yardım istendi",
    "The message was sent to \"{roomName}\"" : "İleti tüm \"{roomName}\" odasına gönderildi",
    "Dismiss request for assistance" : "Yardım isteğini yok say",
    "Send message to room" : "Odaya ileti gönder",
    "Back to main room" : "Ana odaya dön",
    "Back to your room" : "Odanıza dönün",
    "Message all rooms" : "Tüm odalara ileti gönder",
    "Start session" : "Oturumu başlat",
    "Start a call before you start a breakout room session" : "Bir çalışma odası oturumunu başlatmadan önce bir çağrı başlat",
    "Stop session" : "Oturumu bitir",
    "The message was sent to all breakout rooms" : "İleti tüm çalışma odalarına gönderildi",
    "Send a message to all breakout rooms" : "Tüm çalışma odalarına ileti gönder",
    "Breakout rooms are not started" : "Çalışma odaları açılmamış",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Yüksek başarımlı arka yüz olmadan yapılan aramalar bağlantı sorunlarına ve aygıtlarda yüksek yük oluşmasına neden olabilir. {linkstart}Ayrıntılı bilgi alın{linkend}",
    "Talk setup incomplete" : "Konuş kurulumu tamamlanmamış",
    "Disable lobby" : "Giriş kullanılmasın",
    "Settings for participant \"{user}\"" : "\"{user}\" kullanıcısının ayarları",
    "Participant \"{user}\"" : "\"{user}\" katılımcısı",
    "moderator" : "sorumlu",
    "bot" : "bot",
    "guest" : "konuk",
    "Ringing …" : "Çalıyor…",
    "Call rejected" : "Çağrı reddedildi",
    "{time} talking …" : "{time} konuşuyor…",
    "{time} talking time" : "{time} konuşma süresi",
    "Raised their hand" : "Ellerini kaldırdılar",
    "Joined with video" : "Görüntü ile katıldı",
    "Joined via phone" : "Telefon ile katıldı",
    "Joined with audio" : "Ses ile katıldı",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Yazı {maxLength} ya da daha az karakter uzunluğunda olmalıdır. Şu andaki yazı uzunluğu {charactersCount} karakter.",
    "Remove group and members" : "Grubu ve üyeleri sil",
    "Remove team and members" : "Takımı ve üyelerini kaldır",
    "Remove participant" : "Katılımcıyı çıkar",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "\"{displayName}\" grubunu ve üyelerini bu görüşmeden çıkarmak istediğinize emin misiniz?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "\"{displayName}\" takımını ve üyelerini bu görüşmeden çıkarmak istediğinize emin misiniz?",
    "Do you really want to remove {displayName} from this conversation?" : "{displayName} katılımcısını bu görüşmeden çıkarmak istediğinize emin misiniz?",
    "Notification was sent to {displayName}" : "Bildirim {displayName} alıcısına gönderildi",
    "Could not send notification to {displayName}" : "Bildirim {displayName} alıcısına gönderilemedi ",
    "Permissions granted to {displayName}" : "{displayName} için verilmiş izinler",
    "Could not modify permissions for {displayName}" : "{displayName} için izinler değiştirilemedi",
    "Permissions removed for {displayName}" : "{displayName} için izinler kaldırıldı",
    "Permissions set to default for {displayName}" : "{displayName} için izinler varsayılanlara sıfırlandı",
    "Phone number could not be hung up" : "Telefon numarası kapatılamadı",
    "Phone number could not be put on hold" : "Telefon numarası beklemeye alınamadı",
    "Phone number could not be muted" : "Telefon numarasının sesi kısılamadı",
    "Phone number could not be unmuted" : "Telefon numarasının sesi açılamadı",
    "DTMF message could not be sent" : "Arama tonu iletisi gönderilemedi",
    "Phone number copied to clipboard" : "Telefon numarası panoya kopyalandı",
    "Phone number could not be copied" : "Telefon numarası kopyalanamadı",
    "in the lobby" : "girişte",
    "Dial out phone" : "Telefonu ara",
    "Hang up phone" : "Telefonu kapat",
    "Move back to lobby" : "Girişe al",
    "Move to conversation" : "Görüşmeye al",
    "Dial-in PIN" : "Arama PIN kodu",
    "Demote from moderator" : "Sorumluluktan çıkar",
    "Promote to moderator" : "Sorumluluğa yükselt",
    "Resend invitation" : "Daveti yeniden gönder",
    "Send call notification" : "Çağrı bildirimi gönder",
    "Dial out phone number" : "Telefon numarasını ara",
    "Resume call for phone number" : "Telefon numarası çağrısına geri dön",
    "Put phone number on hold" : "Telefon numarası çağrısını beklemeye al",
    "Unmute phone number" : "Telefon numarasının sesini aç",
    "Mute phone number" : "Telefon numarasının sesini kapat",
    "Copy phone number" : "Telefon numarasını kopyala",
    "Reset custom permissions" : "Özel izinleri sıfırla",
    "Grant all permissions" : "Tüm izinleri ver",
    "Remove all permissions" : "Tüm izinleri kaldır",
    "Also ban from this conversation" : "Bu görüşmede de yasaklansın",
    "Internal note (reason to ban)" : "İç not (yasaklama nedeni)",
    "Remove" : "Kaldır",
    "Permissions modified for {displayName}" : "{displayName} için izinler değiştirildi",
    "Add users, groups or teams" : "Kullanıcı, grup ya da takım ekle",
    "Add users or groups" : "Kullanıcı ya da grup ekle",
    "Add users or teams" : "Kullanıcı ya da takım ekle",
    "Add users" : "Kullanıcı ekle",
    "Add groups or teams" : "Grup ya da takım ekle",
    "Add groups" : "Grup ekle",
    "Add teams" : "Takım ekle",
    "Add other sources" : "Başka kaynaklar ekle",
    "Add emails" : "E-posta adreslerini ekle",
    "Integrations" : "Bütünleştirmeler",
    "Add federated users" : "Birleştirilmiş kullanıcılar ekle",
    "Searching …" : "Aranıyor …",
    "Search for more users" : "Diğer kullanıcıları ara",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Katılımcıları, ad, e-posta adresi ya da birleşik bulut kodu ile arayabilirsiniz",
    "Search or add participants" : "Katılımcı arayın ya da ekleyin",
    "Invitation was sent to {actorId}" : "{actorId} için davet gönderildi",
    "An error occurred while adding the participants" : "Katılımcılar eklenirken bir sorun çıktı",
    "A new group conversation with selected participant will be created" : "Seçilmiş katılımcıyla yeni bir grup görüşmesi oluşturulacak",
    "Participants" : "Katılımcılar",
    "Pinned by a deleted user" : "Silinmiş bir kullanıcı sabitlemiş",
    "Participants ({count})" : "Katılımcılar ({count})",
    "Open chat" : "Sohbeti aç",
    "You have new unread messages in the chat." : "Sohbette okumadığınız yeni iletiler var.",
    "You have been mentioned in the chat." : "Sohbette anıldınız.",
    "Search messages" : "İleti arama",
    "Chat" : "Sohbet",
    "Details" : "Ayrıntılar",
    "Shared items" : "Paylaşılmış ögeler",
    "Search in {name}" : "{name} içinde ara",
    "Threads in {name}" : "{name} içindeki yazışmalar",
    "{actor} in {conversation}" : "{actor}, {conversation} içinde",
    "Search messages …" : "İleti ara…",
    "Search options" : "Arama seçenekleri",
    "From User" : "Şu kullanıcıdan",
    "Since" : "Şu zamandan başlayarak",
    "Until" : "Bitiş",
    "No results found" : "Herhangi bir sonuç bulunamadı",
    "Load more results" : "Diğer sonuçları yükle",
    "Recent threads" : "Son yazışmalar",
    "Projects" : "Projeler",
    "No shared items" : "Paylaşılmış bir öge yok",
    "Thread notifications" : "Yazışma bildirimleri",
    "Thread actions" : "Yazışma işlemleri",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Bir görüşme bağlantısı",
    "No open conversations found" : "Açık herhangi bir görüşme yok",
    "Either there are no open conversations or you joined all of them." : "Açık bir görüşme yok ya da tümüne katılmışsınız.",
    "Check spelling or use complete words." : "Yazım denetlensin ya da tam sözcükler kullanılsın.",
    "Search conversations or users" : "Görüşme ya da kullanıcı arama",
    "Select conversation" : "Görüşme seçin",
    "Number length is not valid" : "Numara uzunluğu geçersiz",
    "Region code is not valid" : "Bölge kodu geçersiz",
    "Number length is too short" : "Numara çok kısa",
    "Number length is too long" : "Numara çok uzun",
    "Number is not valid" : "Numara geçersiz",
    "Phone numbers" : "Telefon numaraları",
    "Display name: {name}" : "Görüntülenecek ad: {name}",
    "Edit display name" : "Görüntülenecek adı düzenle",
    "Display name (required)" : "Görüntülenecek ad (zorunlu)",
    "Save name" : "Adı kaydet",
    "I picked message bubbles" : "İleti balonlarını seçtim",
    "I picked the list style" : "Liste biçemini seçtim",
    "Error while setting personal setting" : "Kişisel ayarlarınız kaydedilirken sorun çıktı",
    "Error while saving sounds setting" : "Ses ayarları kaydedilirken sorun çıktı",
    "Compact conversations list" : "Küçük görüşmeler listesi",
    "Chat appearance" : "Sohbet görünümü",
    "Messages list" : "İleti listesi",
    "Message bubbles" : "İleti balonları",
    "Play sounds when participants join or leave a call" : "Katılımcılar çağrıya katıldığında ya da ayrıldığında ses çalınsın",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Üreticinin teknik sınırlamaları nedeniyle şu anda iPad ve iPhone aygıtlarında kullanılamıyor.",
    "Notification settings" : "Bildirim ayarları",
    "Sounds for chat and call notifications" : "Sohbet ve çağrı bildirimlerinin sesleri",
    "Invalid language ({languageId})" : "Dil geçersiz ({languageId})",
    "Default language" : "Varsayılan dil",
    "Default language ({languageName})" : "Varsayılan dil ({languageName})",
    "Error when trying to load the available live translation languages" : "Canlı çeviri için kullanılabilecek diller yüklenirken sorun çıktı",
    "Error when trying to set live translation language" : "Canlı çeviri dili ayarlanırken sorun çıktı",
    "Set language used to show the transcriptions" : "Çevirilerin görüntüleneceği dili seçin",
    "Select location for attachments" : "Ek dosyaların konumunu seçin",
    "Error while setting attachment folder" : "Ek dosyalar klasörü ayarlanırken sorun çıktı",
    "Error while setting read status privacy" : "Okundu durumu gizliliği ayarı kaydedilemedi",
    "Error while setting typing status privacy" : "Yazıyor durumu gizliliği ayarı kaydedilemedi",
    "Error while setting default media state" : "Varsayılan ortam durumu ayarlanırken sorun çıktı",
    "Turn camera and microphone off by default" : "Varsayılan olarak kamera ve mikrofon kapatılsın",
    "Blur camera background by default" : "Varsayılan olarak arka plan bulanıklaştırılsın",
    "Skip device preview before joining a call" : "Bir çağrıya katılmadan önce aygıt ön izleme ekranı görüntülenmesin",
    "Appearance & Sounds" : "Görünüm ve sesler",
    "Privacy" : "Gizlilik",
    "Send read receipts" : "Okundu bilgisi gönderilsin",
    "When off, all read statuses will be hidden" : "Kapatıldığında, tüm okunma durumları gizlenir",
    "Share typing status" : "Yazma durumu paylaşılsın",
    "When off, all typing indicators will be hidden" : "Kapatıldığında, tüm yazma göstergeleri gizlenir",
    "Attachments folder" : "Ek dosya klasörü",
    "Toggle full screen" : "Tam ekrana geç",
    "Return to Home screen" : "Girişe dön",
    "Search" : "Arama",
    "Shortcuts while in a chat" : "Sohbet sırasında kullanılabilecek kısayol tuşları",
    "Focus the chat input" : "Sohbet girişine odaklan",
    "Unfocus the chat input to use shortcuts" : "Kısayol tuşlarını kullanmak için odağı sohbet girişinden al",
    "Edit your last message" : "Son iletinizi düzenleyin",
    "Shortcuts while in a call" : "Çağrı sırasında kullanılabilecek kısayol tuşları",
    "Camera on and off" : "Kamerayı açma ve kapatma",
    "Microphone on and off" : "Mikrofonu açma ve kapatma",
    "Raise or lower hand" : "El kadır ya da indir",
    "Push to talk or push to mute" : "Bas konuş ya da bas kıs",
    "Zoom-in / zoom-out a screen share" : "Bir ekran paylaşımında yakınlaştırma / uzaklaştırma",
    "Mouse wheel" : "Fare tekerleği",
    "Start call silently" : "Çağrıyı sessizce başlat",
    "Start call" : "Çağrıyı başlat",
    "End call" : "Çağrıyı sonlandır",
    "The server was updated, you cannot start or join a call." : "Sunucu güncellenmiş. Bir çağrı başlatamaz ya da katılamazsınız.",
    "This call has just ended" : "Bu çağrı sona erdi",
    "You will be able to join the call only after a moderator starts it." : "Çağrıya ancak bir sorumlu çağrıyı başlattıktan sonra katılabilirsiniz.",
    "End call for everyone" : "Çağrıyı herkes için sonlandır",
    "Starting the recording" : "Kayıt başlatılıyor",
    "Recording" : "Kaydediliyor",
    "The call has been running for one hour." : "Çağrı bir saattir sürüyor.",
    "Cancel recording start" : "Kaydı başlatmaktan vazgeç",
    "Stop recording" : "Kaydı durdur",
    "Send a reaction" : "Tepki ver",
    "React with {reaction}" : "{reaction} ile tepki ver",
    "All tasks done!" : "Tüm görevler tamamlandı!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} / %n görev","{done} / %n görev"],
    "Add participants to this call" : "Bu çağrıya katılımcılar ekle",
    "_%n participant in call_::_%n participants in call_" : ["Çağrıda %n katılımcı var","Çağrıda %n katılımcı var"],
    "Scheduled messages" : "Zamanlanmış iletiler",
    "You are not allowed to enable screensharing" : "Ekranı paylaşma izniniz yok",
    "No screensharing" : "Ekran paylaşımı yok",
    "Screensharing options" : "Ekran paylaşımı ayarları",
    "Enable screensharing" : "Ekranı paylaş",
    "Bad sent video and screen quality." : "Gönderilen görüntü ve ekran kalitesi kötü.",
    "Bad sent screen quality." : "Gönderilen ekran kalitesi kötü.",
    "Bad sent video quality." : "Gönderilen görüntü kalitesi kötü.",
    "Bad sent audio, video and screen quality." : "Gönderilen ses, görüntü ve ekran kalitesi kötü.",
    "Bad sent audio and screen quality." : "Gönderilen ses ve ekran kalitesi kötü.",
    "Bad sent audio and video quality." : "Gönderilen ses ve görüntü kalitesi kötü.",
    "Bad sent audio quality." : "Gönderilen ses kalitesi kötü.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "İnternet bağlantınız ya da bilgisayarınız yoğun kullanıldığından diğer katılımcılar ekranınızı göremeyebilir. Durumu iyileştirmek için ekran paylaşırken arka plan bulanıklaştırmanızı kapatmayı deneyin.",
    "Disable background blur" : "Arka plan bulanıklaştırmayı kapat",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "İnternet bağlantınız ya da bilgisayarınız yoğun kullanıldığından diğer katılımcılar ekranınızı göremeyebilir. Durumu iyileştirmek için ekran paylaşırken kendi görüntünüzü kapatmayı deneyin.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "İnternet bağlantınız ya da bilgisayarınız yoğun kullanıldığından diğer katılımcılar ekran paylaşımınızı göremeyebilir.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "İnternet bağlantınız ya da bilgisayarınız yoğun kullanıldığından diğer katılımcılar sizi göremeyebilir.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "İnternet bağlantınız ya da bilgisayarınız yoğun kullanıldığından diğer katılımcılar sizi anlayamayabilir ve sizi göremeyebilir. Durumu iyileştirmek için ekran paylaşırken arka plan bulanıklaştırmanızı kapatmayı deneyin.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "İnternet bağlantınız ya da bilgisayarınız yoğun kullanıldığından diğer katılımcılar sizi anlamayabilir ve göremeyebilir. Durumu iyileştirmek için ekran paylaşırken kendi görüntünüzü kapatmayı deneyin.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "İnternet bağlantınız ya da bilgisayarınız yoğun kullanıldığından diğer katılımcılar sizi anlamayabilir ve ekranınızı göremeyebilir. Durumu iyileştirmek için ekran paylaşımınızı kapatmayı deneyin.",
    "Disable screenshare" : "Ekran paylaşımını kapat",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "İnternet bağlantınız ya da bilgisayarınız yoğun kullanıldığından diğer katılımcılar sizi anlayamayabilir ve sizi göremeyebilir. Durumu iyileştirmek için arka plan bulanıklaştırmanızı kapatmayı deneyin.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "İnternet bağlantınız ya da bilgisayarınız yoğun kullanıldığından diğer katılımcılar sizi anlamayabilir ve göremeyebilir. Durumu iyileştirmek için kendi görüntünüzü kapatmayı deneyin.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "İnternet bağlantınız ya da bilgisayarınız yoğun kullanıldığından diğer katılımcılar sizi anlamayabilir.",
    "Screen sharing is not supported by your browser." : "Tarayıcınız ekran paylaşımını desteklemiyor.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Ekran paylaşımı yapabilmek için sayfa HTTPS kullanılarak yüklenmelidir.",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekran paylaşımı için sayfa HTTPS kullanılarak yüklenmiş olmalıdır.",
    "An error occurred while starting screensharing." : "Ekran paylaşımı başlatılırken bir sorun çıktı.",
    "Select virtual background" : "Sanal arka planı seçin",
    "Show your screen" : "Ekranımı görüntüle",
    "Stop screensharing" : "Ekran paylaşımını durdur",
    "Mute others" : "Diğerlerinin sesini kıs",
    "Start recording" : "Kaydı başlat",
    "Set up breakout rooms" : "Çalışma odalarını hazırla",
    "Download attendance list" : "Katılımcı listesini indir",
    "Open Calendar" : "Takvimi aç",
    "Remove participant {name}" : "{name} katılımcısını çıkar",
    "Would you like to delete this conversation?" : "Bu görüşmeyi silmek ister misiniz?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["Bu görüşme, %n gün boyunca etkileşim olmazsa herkesten otomatik olarak silinecek.","Bu görüşme, %n gün boyunca etkileşim olmazsa herkesten otomatik olarak silinecek."],
    "Are you sure you want to delete this conversation?" : "Bu görüşmeyi silmek istediğinize emin misiniz?",
    "Delete now" : "Şimdi sil",
    "Keep" : "Tut",
    "Open dialpad" : "Numara klavyesini aç",
    "Select a region" : "Bir bölge seçin",
    "Local time: {time}" : "Yerel zaman: {time}",
    "Scheduled {datetime}" : "{datetime} zamanına ayarlanmış",
    "Scheduled for {datetime}" : "{datetime} için zamanlanmış",
    "Search …" : "Arama…",
    "Message without mention" : "Anma olmadan ileti",
    "Mention myself" : "Beni an",
    "Mention everyone" : "Herkesi an",
    "Select a conversation" : "Bir görüşme seçin",
    "Select a mode" : "Bir kip seçin",
    "You do not have permissions to access this conversation." : "Bu görüşmeye erişme izniniz yok.",
    "Join a different conversation or start a new one." : "Başka bir görüşmeye katılın ya da yeni bir görüşme başlatın.",
    "The conversation does not exist" : "Görüşme bulunamadı",
    "Join a conversation or start a new one!" : "Var olan bir görüşmeye katılın ya da yeni bir görüşme başlatın!",
    "Duplicate session" : "Çift oturum",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "Bu görüşme başka bir sekmede de açılmış. Geçerli sunucu sürümü, bir konuşmanın birden fazla sekmede açılmasını desteklemiyor.",
    "Creating and joining a conversation with \"{userid}\"" : "\"{userid}\" ile görüşme başlatılıyor",
    "Join a conversation or start a new one" : "Bir görüşmeye katılın ya da yeni bir görüşme başlatın",
    "Error while joining the conversation" : "Görüşmeye katılırken sorun çıktı",
    "Another user" : "Başka bir kullanıcı",
    "Hey! Are you using the list style or message bubbles?" : "Liste biçimini mi ileti balonları biçemini mi kullanıyorsunuz?",
    "Nextcloud URL" : "Nextcloud adresi",
    "Nextcloud user" : "Nextcloud kullanıcısı",
    "User password" : "Kullanıcı parolası",
    "Talk conversation" : "Konuş görüşmesi",
    "Skip TLS verification" : "TLS doğrulaması atlansın",
    "Matrix server URL" : "Matrix sunucusu adresi",
    "User" : "Kullanıcı",
    "Matrix channel" : "Matrix kanalı",
    "Mattermost server URL" : "Mattermost sunucu adresi",
    "Mattermost user" : "Mattermost kullanıcısı",
    "Team name" : "Takım adı",
    "Channel name" : "Kanal adı",
    "Rocket.Chat server URL" : "Rocket.Chat sunucusunun adresi",
    "User name or email address" : "Kullanıcı adı ya da e-posta adresi",
    "Rocket.Chat channel" : "Rocket.Chat kanalı",
    "Zulip server URL" : "Zulip sunucusunun adresi",
    "Bot user name" : "Bot kullanıcı adı",
    "Bot API key" : "Bot API anahtarı",
    "Zulip channel" : "Zulip kanalı",
    "API token" : "API kodu",
    "Slack channel" : "Slack kanalı",
    "Server ID or name" : "Sunucu kimliği ya da adı",
    "Channel ID (prefixed with \"ID:\") or name" : "Kanal kimliği (\"ID:\"  ön ekiyle) ya da ad",
    "Channel" : "Kanal",
    "Login" : "Oturum aç",
    "Chat ID" : "Sohbet kimliği",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC sunucusunun adresi (örnek: chat.freenode.net:6667)",
    "Nickname" : "Takma ad",
    "Connection password" : "Bağlantı parolası",
    "IRC channel" : "IRC kanalı",
    "Channel password" : "Kanal parolası",
    "NickServ nickname" : "NickServ takma adı",
    "NickServ password" : "NickServ parolası",
    "Use TLS" : "TLS kullanılsın",
    "Use SASL" : "SASL kullanılsın",
    "Tenant ID" : "Kiracı kimliği",
    "Client ID" : "İstemci kimliği",
    "Team ID" : "Takım kimliği",
    "Thread ID" : "Konu kimliği",
    "XMPP/Jabber server URL" : "XMPP/Jabber sunucusunun adresi",
    "MUC server URL" : "MUC sunucusunun adresi",
    "Jabber ID" : "Jabber kimliği",
    "Pinned messages" : "Sabitlenmiş iletiler",
    "Media" : "Ortam",
    "Polls" : "Anketler",
    "Deck cards" : "Tahta kartları",
    "Voice messages" : "Sesli iletiler",
    "Locations" : "Konumlar",
    "Call recordings" : "Çağrı kayıtları",
    "Audio" : "Ses",
    "Show all pinned messages" : "Tüm sabitlenmiş iletileri görüntüle",
    "Show all media" : "Tüm ortamları görüntüle",
    "Show all files" : "Tüm dosyaları görüntüle",
    "Show all polls" : "Tüm anketleri görüntüle",
    "Show all deck cards" : "Tüm tahta kartlarını görüntüle",
    "Show all voice messages" : "Tüm sesli iletileri görüntüle",
    "Show all locations" : "Tüm konumları görüntüle",
    "Show all call recordings" : "Tüm çağrı kayıtlarını görüntüle",
    "Show all audio" : "Tüm sesleri görüntüle",
    "Show all other" : "Tüm diğerlerini görüntüle",
    "Follow conversation settings" : "Görüşme ayarları kullanılsın",
    "Group" : "Grup",
    "Team" : "Takım",
    "You reconnected to the call" : "Çağrı ile yeniden bağlantı kurdunuz",
    "{actor} reconnected to the call" : "{actor} çağrı ile yeniden bağlantı kurdu",
    "You added {user0} and {user1}" : "{user0} ve {user1} kullanıcılarını eklediniz",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["{user0}, {user1} ve %n diğer katılımcıyı eklediniz","{user0}, {user1} ve %n diğer katılımcıyı eklediniz"],
    "An administrator added you and {user0}" : "Bir yönetici sizi ve {user0} kullanıcısını ekledi",
    "{actor} added you and {user0}" : "{actor} sizi ve {user0} kullanıcısını ekledi",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Bir yönetici sizi, {user0} kullanıcısını ve %n diğer katılımcıyı ekledi","Bir yönetici sizi, {user0} kullanıcısını ve %n diğer katılımcıyı ekledi"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} sizi, {user0} kullanıcısını ve %n diğer katılımcıyı ekledi","{actor} sizi, {user0} kullanıcısını ve %n diğer katılımcıyı ekledi"],
    "An administrator added {user0} and {user1}" : "Bir yönetici {user0} ve {user1} kullanıcısını ekledi",
    "{actor} added {user0} and {user1}" : "{actor}, {user0} ve {user1} kullanıcılarını ekledi",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Bir yönetici, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı ekledi","Bir yönetici, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı ekledi"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor}, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı ekledi","{actor}, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı ekledi"],
    "You removed {user0} and {user1}" : "{user0} ve {user1} kullanıcılarını çıkardınız",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["{user0}, {user1} ve %n diğer katılımcıyı çıkardınız","{user0}, {user1} ve %n diğer katılımcıyı çıkardınız"],
    "An administrator removed you and {user0}" : "Bir yönetici sizi ve {user0} kullanıcısını çıkardı",
    "{actor} removed you and {user0}" : "{actor} sizi ve {user0} kullanıcısını çıkardı",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Bir yönetici sizi, {user0} kullanıcısını ve %n diğer katılımcıyı çıkardı","Bir yönetici sizi, {user0} kullanıcısını ve %n diğer katılımcıyı çıkardı"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} sizi, {user0} kullanıcısını ve %n diğer katılımcıyı çıkardı","{actor} sizi, {user0} kullanıcısını ve %n diğer katılımcıyı çıkardı"],
    "An administrator removed {user0} and {user1}" : "Bir yönetici {user0} ve {user1} kullanıcılarını çıkardı",
    "{actor} removed {user0} and {user1}" : "{actor}, {user0} ve {user1} kullanıcılarını çıkardı",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Bir yönetici, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı çıkardı","Bir yönetici, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı çıkardı"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor}, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı çıkardı","{actor}, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı çıkardı"],
    "You and {user0} joined the call" : "Siz ve {user0} kullanıcısı çağrıya katıldı",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Siz, {user0} ve %n diğer katılımcı çağrıya katıldı","Siz, {user0} ve %n diğer katılımcı çağrıya katıldı"],
    "{user0} and {user1} joined the call" : "{user0} ve {user1} çağrıya katıldı",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} ve %n diğer katılımcı çağrıya katıldı","{user0}, {user1} ve %n diğer katılımcı çağrıya katıldı"],
    "You and {user0} left the call" : "Siz ve {user0} çağrıdan ayrıldınız",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Siz, {user0} ve %n diğer katılımcı çağrıdan ayrıldı","Siz, {user0} ve %n diğer katılımcı çağrıdan ayrıldı"],
    "{user0} and {user1} left the call" : "{user0} ve {user1} çağrıdan ayrıldı",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} ve %n diğer katılımcı çağrıdan ayrıldı","{user0}, {user1} ve %n diğer katılımcı çağrıdan ayrıldı"],
    "You promoted {user0} and {user1} to moderators" : "{user0} ve {user1} kullanıcılarını sorumluluğa yükselttiniz",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["{user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı sorumluluğa yükselttiniz","{user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı sorumluluğa yükselttiniz"],
    "An administrator promoted you and {user0} to moderators" : "Bir yönetici sizi ve {user0} kullanıcısını sorumluluğa yükseltti",
    "{actor} promoted you and {user0} to moderators" : "{actor}, sizi ve {user0} kullanıcısını sorumluluğa yükseltti",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Bir yönetici sizi, {user0} kullanıcısını ve %n diğer katılımcıyı sorumluluğa yükseltti","Bir yönetici sizi, {user0} kullanıcısını ve %n diğer katılımcıyı sorumluluğa yükseltti"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} sizi, {user0} kullanıcısını ve %n diğer katılımcıyı sorumluluğa yükseltti","{actor} sizi, {user0} kullanıcısını ve %n diğer katılımcıyı sorumluluğa yükseltti"],
    "An administrator promoted {user0} and {user1} to moderators" : "Bir yönetici {user0} ve {user1} kullanıcısını sorumluluğa yükseltti",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor}, {user0} ve {user1} kullanıcılarını sorumluluğa yükseltti",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Bir yönetici, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı sorumluluğa yükseltti","Bir yönetici, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı sorumluluğa yükseltti"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor}, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı sorumluluğa yükseltti","{actor}, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı sorumluluğa yükseltti"],
    "You demoted {user0} and {user1} from moderators" : "{user0} ve {user1} kullanıcılarını sorumluluktan çıkardınız",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["{user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı sorumluluktan çıkardınız","{user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı sorumluluktan çıkardınız"],
    "An administrator demoted you and {user0} from moderators" : "Bir yönetici sizi ve {user0} kullanıcısını sorumluluktan çıkardı",
    "{actor} demoted you and {user0} from moderators" : "{actor}, sizi ve {user0} kullanıcısını sorumluluktan çıkardı",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Bir yönetici sizi, {user0} kullanıcısını ve %n diğer katılımcıyı sorumluluktan çıkardı","Bir yönetici sizi, {user0} kullanıcısını ve %n diğer katılımcıyı sorumluluktan çıkardı"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} sizi, {user0} kullanıcısını ve %n diğer katılımcıyı sorumluluktan çıkardı","{actor} sizi, {user0} kullanıcısını ve %n diğer katılımcıyı sorumluluktan çıkardı"],
    "An administrator demoted {user0} and {user1} from moderators" : "Bir yönetici {user0} ve {user1} kullanıcısını sorumluluktan çıkardı",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor}, {user0} ve {user1} kullanıcılarını sorumluluktan çıkardı",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Bir yönetici, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı sorumluluktan çıkardı","Bir yönetici, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı sorumluluktan çıkardı"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor}, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı sorumluluktan çıkardı","{actor}, {user0} ve {user1} kullanıcıları ile %n diğer katılımcıyı sorumluluktan çıkardı"],
    "You:" : "Siz:",
    "You: {lastMessage}" : "Siz: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "Sunucu güncellenmiş.",
    "(edited by you)" : "(sizin tarafından düzenlendi)",
    "(edited by a deleted user)" : "(silinmiş bir kullanıcı tarafından düzenlendi)",
    "(edited by {moderator})" : "({moderator} tarafından düzenlendi)",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Başka bir pencereden ya da aygıttan da katıldığınız görüşmeye yeniden katılmaya çalışıyorsunuz. Nextcloud Konuş henüz bu özelliği desteklemiyor. Ne yapmak istersiniz?",
    "Leave this page" : "Sayfadan ayrılmak",
    "Join here" : "Buradan katılmak",
    "Deck card has been posted to {conversation}" : "{conversation} görüşmesine Tahta kartı yapıştırıldı",
    "An error occurred while posting deck card to conversation" : "Tahta kartı seçilmiş görüşmeye gönderilirken bir sorun çıktı",
    "Post to a conversation" : "Bir görüşmeye gönder",
    "Post to conversation" : "Görüşmeye gönder",
    "The recording failed. Please contact your administrator." : "Kayıt yapılamadı. lütfen yöneticiniz ile görüşün.",
    "Location has been posted to {conversation}" : "{conversation} görüşmesine Konum yapıştırıldı",
    "An error occurred while posting location to conversation" : "Konum seçilmiş görüşmeye gönderilirken bir sorun çıktı.",
    "Share to a conversation" : "Bir görüşmeye gönder",
    "Share to conversation" : "Görüşmeye gönder",
    "In conversation" : "Görüşmede",
    "Search in conversation: {conversation}" : "{conversation} görüşmesinde ara",
    "Your requests are throttled at the moment due to brute force protection" : "İsteğiniz kaba kuvvet saldırısı koruması tarafından bir süreliğine yavaşlatıldı",
    "Error while clearing conversation history" : "Görüşme geçmişi temizlenirken sorun çıktı",
    "Error occurred while allowing guests" : "Konuklar kabul edilirken sorun çıktı",
    "Error occurred while disallowing guests" : "Konuklar reddedilirken sorun çıktı",
    "Error occurred when restricting the conversation to moderator" : "Görüşmede yalnızca sorumluya izin verilirken sorun çıktı",
    "Error occurred when opening the conversation to everyone" : "Görüşmede herkese izin verilirken sorun çıktı",
    "Conversation password has been saved" : "Görüşme parolası kaydedildi",
    "Conversation password has been removed" : "Görüşme parolası kaldırıldı",
    "Error occurred while saving conversation password" : "Görüşme parolası kaydedilirken sorun çıktı",
    "Call recording is starting." : "Çağrı kaydı başlatılıyor.",
    "Call recording stopped while starting." : "Çağrı kaydı başlatılırken durduruldu.",
    "Call recording stopped. You will be notified once the recording is available." : "Çağrı kaydı durduruldu. Kayıt kullanılabilir olduğunda bilgilendirileceksiniz.",
    "Conversation picture set" : "Görüşme fotoğrafı ayarlandı",
    "Conversation picture deleted" : "Görüşme fotoğrafı silindi",
    "Could not delete the conversation picture" : "Görüşme fotoğrafı silinemedi",
    "Could not remove the automatic expiration" : "Otomatik silme süresi kaldırılamadı",
    "Could not post message: {errorMessage}" : "İleti gönderilemedi: {errorMessage}",
    "Participant is banned successfully" : "Katılımcı yasaklandı",
    "Error while banning the participant" : "Katılımcı yasaklanırken sorun çıktı",
    "An error occurred while fetching the participants" : "Katılımcılar alınırken bir sorun çıktı",
    "Could not send invitation to {actorId}" : "{actorId} için davet gönderilirken sorun çıktı",
    "Invitations sent" : "Davetler gönderildi",
    "Error occurred when sending invitations" : "Davetler gönderilirken sorun çıktı",
    "Failed to join the conversation." : "Görüşmeye girilemedi.",
    "An error occurred while creating breakout rooms" : "Çalışma odaları oluşturulurken bir sorun çıktı",
    "An error occurred while re-ordering the attendees" : "Katılımcılar yeniden sıralanırken bir sorun çıktı",
    "An error occurred while deleting breakout rooms" : "Çalışma odaları silinirken bir sorun çıktı",
    "An error occurred while starting breakout rooms" : "Çalışma odaları açılırken bir sorun çıktı",
    "An error occurred while stopping breakout rooms" : "Çalışma odaları kapatılırken bir sorun çıktı",
    "An error occurred while sending a message to the breakout rooms" : "Çalışma odalarına ileti gönderilirken bir sorun çıktı",
    "An error occurred while requesting assistance" : "Yardım istenirken bir sorun çıktı",
    "An error occurred while resetting the request for assistance" : "Yardım isteği sıfırlanırken bir sorun çıktı",
    "An error occurred while joining breakout room" : "Çalışma odasına geçilirken bir sorun çıktı",
    "Failed to rename the thread" : "Yazışma yeniden adlandırılamadı",
    "Error fetching upcoming events" : "Yaklaşan etkinlikler alınırken sorun çıktı",
    "Error fetching upcoming reminders" : "Yaklaşan anımsatıcılar alınırken sorun çıktı",
    "An error occurred while accepting an invitation" : "Bir davet kabul edilirken bir sorun çıktı",
    "An error occurred while rejecting an invitation" : "Bir davet reddedilirken bir sorun çıktı",
    "{guest} (guest)" : "{guest} (konuk)",
    "Poll draft has been saved" : "Anket taslağı kaydedildi",
    "An error occurred while saving the draft" : "Anket taslağı kaydedilirken bir sorun çıktı",
    "An error occurred while submitting your vote" : "Oyunuz gönderilirken bir sorun çıktı",
    "An error occurred while ending the poll" : "Anket sona erdirilirken bir sorun çıktı",
    "An error occurred while deleting the poll draft" : "Anket taslağı silinirken bir sorun çıktı",
    "Poll \"{name}\" was created by {user}. Click to vote" : "{user}, \"{name}\" anketini oluşturdu. Oy vermek için tıklayın",
    "Failed to add reaction" : "Tepki eklenemedi",
    "Failed to remove reaction" : "Tepki silinemedi",
    "The server is in maintenance mode." : "Sunucu bakım kipinde.",
    "Federated server was updated." : "Birleşik sunucu güncellenmiş.",
    "Error while uploading file \"{fileName}\"" : "\"{fileName}\" dosyası yüklenirken sorun çıktı",
    "Not enough free space to upload file \"{fileName}\"" : "\"{fileName}\" dosyasını yüklemek için yeterli boş alan yok",
    "You are not allowed to share files" : "Dosya paylaşma izniniz yok",
    "Error while sharing file" : "Dosya paylaşılırken sorun çıktı",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Kullandığınız tarayıcı Nextcloud Konuş uygulaması tarafından tam olarak desteklenmiyor. Lütfen güncel Mozilla Firefox, Microsoft Edge, Google Chrome, Opera ya da Apple Safari sürümünü kullanın.",
    "_In %n hour_::_In %n hours_" : ["%n saat sonra","%n saat sonra"],
    "_%n minute _::_%n minutes_" : ["%n dakika ","%n dakika"],
    "In {hours} and {minutes}" : "{hours} : {minutes} sonra",
    "_In %n minute_::_In %n minutes_" : ["%n dakika sonra","%n dakika sonra"],
    "Later today – {timeLocale}" : "Bugün daha sonra – {timeLocale}",
    "Set time for later today" : "Bugün daha sonrası için ayarla",
    "Tomorrow – {timeLocale}" : "Yarın – {timeLocale}",
    "Set time for tomorrow" : "Yarın için ayarla",
    "This weekend – {timeLocale}" : "Bu hafta sonu – {timeLocale}",
    "Set time for this weekend" : "Bu hafta sonu için ayarla",
    "Next week – {timeLocale}" : "Sonraki hafta – {timeLocale}",
    "Set time for next week" : "Gelecek hafta için ayarla",
    "Message link copied to clipboard" : "İleti bağlantısı panoya kopyalandı",
    "Conversation link copied to clipboard" : "Görüşme bağlantısı panoya kopyalandı",
    "The link could not be copied" : "Bağlantı kopyalanamadı",
    "Error while parsing a PROPFIND error" : "PROPFIND hatası işlenirken sorun çıktı",
    "Sending signaling message has failed" : "Signaling iletisi gönderilemedi",
    "Lost connection to signaling server. Trying to reconnect." : "Signalling sunucusu ile bağlantı kesildi. Bağlantı yeniden kurulmaya çalışılıyor.",
    "Lost connection to signaling server." : "Signalling sunucusu ile bağlantı kesildi.",
    "Connecting is taking longer than expected …" : "Bağlantı kurulması beklenenden uzun sürüyor…",
    "Failed to connect. Retrying …" : "Bağlantı kurulamadı. Yeniden deneniyor…",
    "Failed to connect. The signaling server may be set up incorrectly" : "Bağlantı kurulamadı. Signalling sunucusu yanlış yapılandırılmış olabilir",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Bu Konuş sürümü ile uyumlu olması için yapılandırılmış signalling sunucusunun güncellenmesi gerekiyor. Lütfen yöneticiniz ile görüşün.",
    "Please restart the app." : "Lütfen uygulamayı yeniden başlatın.",
    "Please reload the page." : "Lütfen sayfayı yeniden yükleyin.",
    "Please try to restart the app." : "Lütfen uygulamayı yeniden başlatmayı deneyin.",
    "Please try to reload the page." : "Lütfen sayfayı yeniden yüklemeyi deneyin.",
    "Do not disturb" : "Rahatsız etmeyin",
    "Away" : "Uzakta",
    "Microphone {number}" : "{number}. mikrofon",
    "Camera {number}" : "{number}. kamera",
    "Speaker {number}" : "{number}. hoparlör",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Mikrofonunuz kapalıyken konuşuyorsunuz gibi görünüyor. Lütfen diğer katılımcıların sizi duyabilmesi için mikrofonunuzu açın",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "En az bir katılımcı ile bağlantı kurulamadı. Kullanım şekliniz için bir TURN sunucusuna gerek olabilir. Lütfen BT yöneticinizden {linkstart}bu belgeye bakarak{linkend} bir TURN sunucusu kurmasını isteyin.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "İşlemin tamamlanması beklendiğinden uzun sürüyor. Ortam izinleri zaten verilmiş (ya da reddedilmiş) olabilir mi? Yanıt evet ise ses ve görüntülerde sorun çıkacağından lütfen tarayıcınızı yeniden başlatın.",
    "Access to microphone & camera is only possible with HTTPS" : "Kamera ve mikrofona yalnızca HTTPS üzerinden erişilebilir",
    "Please move your setup to HTTPS" : "Lütfen kurulumunuzu HTTPS üzerine geçirin",
    "Access to microphone & camera was denied" : "Mikrofon ve kameraya erişim reddedildi",
    "WebRTC is not supported in your browser" : "WebRTC tarayıcınız tarafından desteklenmiyor",
    "Please use a different browser like Firefox or Chrome" : "Lütfen Firefox ya da Chrome gibi farklı bir tarayıcı kullanın",
    "Error while accessing microphone & camera" : "Mikrofon ve kameraya erişilirken sorun çıktı",
    "%s Talk on your mobile devices" : "Mobil aygıtlarınızda %s Konuş uygulaması",
    "Join conversations at any time, anywhere, on any device." : "Görüşmelere istediğiniz yerden, istediğiniz zamanda, istediğiniz aygıt ile katılabilirsiniz.",
    "Android app" : "Android uygulaması",
    "iOS app" : "iOS uygulaması",
    "__language_name__" : "Türkçe",
    "Webhook Demo" : "İnternet kancası örneği",
    "Call summary (%s)" : "Çağrı özeti (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Çağrı özeti botu, çağrıdan sonra tüm katılımcıları listeleyen ve görevleri özetleyen bir özet iletisi gönderir.",
    "Tasks" : "Görevler",
    "Notes" : "Notlar",
    "Reports" : "Raporlar",
    "Decisions" : "Kararlar",
    "Agenda" : "Gündem",
    "Call summary" : "Çağrı özeti",
    "Call summary - {title}" : "Çağrı özeti - {title}",
    "Talk conversation for event" : "Etkinlik için Konuş görüşmesi",
    "Client Push is installed, this improves the performance of desktop clients." : "Client Push kuruldu. Bilgisayar istemci yazılımlarının başarımını artırır.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} kurulmamış. Bilgisayar istemci yazılımları kullanılırken başarım sorunları yaşanabilir.",
    "Next meeting" : "Sonraki toplantı",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Takviminizde bir toplantı zamanlayın. Burada görüntülenmesi için bir Konuş görüşmesinin konum olarak ayarlanması gerekir",
    "Join conversations from remote Nextcloud servers" : "Uzak Nextcloud sunucularındaki görüşmelere katıl",
    "Your default media state has been saved" : "Varsayılan ortam durumunuz kaydedildi",
    "Set reminder for later today" : "Bugün daha sonrası için anımsatıcı ayarla",
    "Set reminder for tomorrow" : "Yarın için anımsatıcı ayarla",
    "Set reminder for this weekend" : "bu hafta sonu için anımsatıcı ayarla",
    "Set reminder for next week" : "Gelecek hafta için anımsatıcı ayarla",
    "Generate summary" : "Özet oluşturulsun",
    "Open poll • You voted already" : "Açık anket • Zaten oy vermişsiniz",
    "Open poll • Click to vote" : "Açık anket • Oy vermek için tıklayın",
    "Poll • Ended" : "Anket • Sona ermiş",
    "Talk recording from {time} ({conversation})" : "Konuş kaydediyor {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Anket sonuçları • %n oy","Anket sonuçları • %n oy"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Açık anket • %n oy","Açık anket • %n oy"],
    "Submit vote" : "Oyu gönder",
    "Your privacy setting has been saved" : "Gizlilik ayarınız kaydedildi",
    "Your personal setting has been saved" : "Kişisel ayarlarınız kaydedildi",
    "Failed to save sounds setting" : "Ses ayarları kaydedilemedi",
    "Sounds setting saved" : "Ses ayarları kaydedildi",
    "Always shown if recording consent is required" : "Kayıt alma rızası isteniyorsa her zaman görüntülenir",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Konuş güncellenmiş. Bir çağrı başlatamaz ya da katılamazsınız.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Görüşmeye başka bir pencereden ya da aygıttan da katılmışsınız. Nextcloud Konuş henüz bu özelliği desteklemediği için bu oturum kapatılacak.",
    "Nextcloud Talk was updated." : "Nextcloud Konuş güncellenmiş.",
    "Nextcloud is in maintenance mode." : "Nextcloud bakım kipinde.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Konuş birliği güncellenmiş.",
    "Enable live translation" : "Canlı çeviriyi aç",
    "I picked list style" : "Liste biçemini seçtim",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Talk görünümü liste olarak mı ileti balonları olarak mı kullanıyorsunuz?"
},
"nplurals=2; plural=(n > 1);");
